@@ -1,3 +1,6 @@
+"""Docstrings for the methods. They are meant to be used in the init docstrings of
+the transformers."""
+
 _fit_not_learn_docstring = """fit:
         This transformer does not learn parameters.
         """.rstrip()
@@ -28,3 +31,17 @@ _transform_encoders_docstring = """transform:
 _transform_creation_docstring = """transform:
         Create new features.
     """.rstrip()
+
+# used in discretisers module
+_fit_discretiser_docstring = """fit:
+        Find the interval limits.
+    """.rstrip()
+
+_transform_discretiser_docstring = """transform:
+        Sort continuous variable values into the intervals.
+    """.rstrip()
+
+# used in imputation module
+_transform_imputers_docstring = """transform:
+        Impute missing data.
+    """.rstrip()
