@@ -7,7 +7,7 @@ from feature_engine._docstrings.fit_attributes import (
     _n_features_in_docstring,
     _variables_attribute_docstring,
 )
-from feature_engine._docstrings.init_parameters import (
+from feature_engine._docstrings.init_parameters.all_trasnformers import (
     _drop_original_docstring,
     _missing_values_docstring,
 )
@@ -100,6 +100,36 @@ class MathFeatures(BaseCreation):
 
     In insurance, we can sum the damage to various parts of a car to obtain the
     total damage.
+
+    Examples
+    --------
+
+    >>> import pandas as pd
+    >>> from feature_engine.creation import MathFeatures
+    >>> X = pd.DataFrame(dict(x1 = [1,2,3], x2 = [4,5,6]))
+    >>> mf = MathFeatures(variables = ["x1","x2"], func = "sum")
+    >>> mf.fit(X)
+    >>> mf.transform(X)
+       x1  x2  sum_x1_x2
+    0   1   4          5
+    1   2   5          7
+    2   3   6          9
+
+    >>> mf = MathFeatures(variables = ["x1","x2"], func = "prod")
+    >>> mf.fit(X)
+    >>> mf.transform(X)
+       x1  x2  prod_x1_x2
+    0   1   4           4
+    1   2   5          10
+    2   3   6          18
+
+    >>> mf = MathFeatures(variables = ["x1","x2"], func = "mean")
+    >>> mf.fit(X)
+    >>> mf.transform(X))
+       x1  x2  mean_x1_x2
+    0   1   4         2.5
+    1   2   5         3.5
+    2   3   6         4.5
     """
 
     def __init__(
@@ -172,7 +202,7 @@ class MathFeatures(BaseCreation):
         X_new: Pandas dataframe, shape = [n_samples, n_features + n_operations]
             The input dataframe plus the new variables.
         """
-        X = super().transform(X)
+        X = self._check_transform_input_and_state(X)
 
         new_variable_names = self._get_new_features_name()
 
@@ -198,7 +228,7 @@ class MathFeatures(BaseCreation):
 
             if isinstance(self.func, list):
                 functions = [
-                    fun if type(fun) == str else fun.__name__ for fun in self.func
+                    fun if type(fun) is str else fun.__name__ for fun in self.func
                 ]
                 feature_names = [
                     f"{function}_{'_'.join(varlist)}" for function in functions
