@@ -9,6 +9,9 @@ from sklearn.base import BaseEstimator, TransformerMixin
 from sklearn.utils.validation import check_is_fitted
 
 from feature_engine._base_transformers.mixins import GetFeatureNamesOutMixin
+from feature_engine._check_init_parameters.check_variables import (
+    _check_variables_input_value,
+)
 from feature_engine._docstrings.fit_attributes import (
     _feature_names_in_docstring,
     _n_features_in_docstring,
@@ -18,15 +21,6 @@ from feature_engine._docstrings.methods import (
     _fit_transform_docstring,
 )
 from feature_engine._docstrings.substitute import Substitution
-from feature_engine._variable_handling.init_parameter_checks import (
-    _check_init_parameter_variables,
-)
-from feature_engine._variable_handling.variable_type_checks import (
-    _is_categorical_and_is_datetime,
-)
-from feature_engine._variable_handling.variable_type_selection import (
-    _find_or_check_datetime_variables,
-)
 from feature_engine.dataframe_checks import (
     _check_contains_na,
     _check_X_matches_training_df,
@@ -38,6 +32,11 @@ from feature_engine.datetime._datetime_constants import (
     FEATURES_SUFFIXES,
     FEATURES_SUPPORTED,
 )
+from feature_engine.variable_handling._variable_type_checks import (
+    _is_categorical_and_is_datetime,
+)
+from feature_engine.variable_handling.check_variables import check_datetime_variables
+from feature_engine.variable_handling.find_variables import find_datetime_variables
 
 
 @Substitution(
@@ -46,7 +45,7 @@ from feature_engine.datetime._datetime_constants import (
     fit=_fit_not_learn_docstring,
     fit_transform=_fit_transform_docstring,
 )
-class DatetimeFeatures(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin):
+class DatetimeFeatures(TransformerMixin, BaseEstimator, GetFeatureNamesOutMixin):
     """
     DatetimeFeatures extracts date and time features from datetime variables, adding
     new columns to the dataset. DatetimeFeatures can extract datetime information from
@@ -125,6 +124,14 @@ class DatetimeFeatures(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin)
         Return UTC DatetimeIndex if True (converting any tz-aware datetime.datetime
         objects as well). Same as in `pandas.to_datetime`.
 
+    format: str, default None
+        The strftime to parse time, e.g. "%d/%m/%Y". Check pandas `to_datetime()` for
+        more information on choices. If you have variables with different formats pass
+        “mixed”, to infer the format for each element individually. This is risky,
+        and you should probably use it along with dayfirst, according to pandas'
+        documentation.
+
+
     Attributes
     ----------
     variables_:
@@ -152,6 +159,20 @@ class DatetimeFeatures(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin)
     --------
     pandas.to_datetime
     pandas.dt
+
+    Examples
+    --------
+
+    >>> import pandas as pd
+    >>> from feature_engine.datetime import DatetimeFeatures
+    >>> X = pd.DataFrame(dict(date = ["2022-09-18", "2022-10-27", "2022-12-24"]))
+    >>> dtf = DatetimeFeatures(features_to_extract = ["year", "month", "day_of_month"])
+    >>> dtf.fit(X)
+    >>> dtf.transform(X)
+        date_year  date_month  date_day_of_month
+    0       2022           9                 18
+    1       2022          10                 27
+    2       2022          12                 24
     """
 
     def __init__(
@@ -163,6 +184,7 @@ class DatetimeFeatures(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin)
         dayfirst: bool = False,
         yearfirst: bool = False,
         utc: Union[None, bool] = None,
+        format: Union[None, str] = None,
     ) -> None:
 
         if features_to_extract:
@@ -196,13 +218,14 @@ class DatetimeFeatures(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin)
         if utc is not None and not isinstance(utc, bool):
             raise ValueError("utc takes only booleans or None. " f"Got {utc} instead.")
 
-        self.variables = _check_init_parameter_variables(variables)
+        self.variables = _check_variables_input_value(variables)
         self.drop_original = drop_original
         self.missing_values = missing_values
         self.dayfirst = dayfirst
         self.yearfirst = yearfirst
         self.utc = utc
         self.features_to_extract = features_to_extract
+        self.format = format
 
     def fit(self, X: pd.DataFrame, y: Optional[pd.Series] = None):
         """
@@ -234,17 +257,19 @@ class DatetimeFeatures(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin)
             ):
                 raise TypeError("The dataframe index is not datetime.")
 
-            if self.missing_values == "raise":
-                self._check_index_contains_na(X.index)
+            self.variables_ = []
 
-            self.variables_ = None
+        elif self.variables is None:
+            self.variables_ = find_datetime_variables(X)
 
         else:
-            # find or check for datetime variables
-            self.variables_ = _find_or_check_datetime_variables(X, self.variables)
+            self.variables_ = check_datetime_variables(X, self.variables)
 
-            # check if datetime variables contains na
-            if self.missing_values == "raise":
+        # check if datetime variables contains na
+        if self.missing_values == "raise":
+            if self.variables == "index":
+                self._check_index_contains_na(X.index)
+            else:
                 _check_contains_na(X, self.variables_)
 
         if self.features_to_extract is None:
@@ -290,7 +315,7 @@ class DatetimeFeatures(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin)
         X = X[self.feature_names_in_]
 
         # special case index
-        if self.variables_ is None:
+        if self.variables == "index":
             # check if dataset contains na
             if self.missing_values == "raise":
                 self._check_index_contains_na(X.index)
@@ -302,6 +327,7 @@ class DatetimeFeatures(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin)
                     dayfirst=self.dayfirst,
                     yearfirst=self.yearfirst,
                     utc=self.utc,
+                    format=self.format,
                 ),
                 index=X.index,
             )
@@ -323,22 +349,13 @@ class DatetimeFeatures(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin)
                         dayfirst=self.dayfirst,
                         yearfirst=self.yearfirst,
                         utc=self.utc,
+                        format=self.format,
                     )
                     for variable in self.variables_
                 ],
                 axis=1,
             )
 
-            non_dt_columns = datetime_df.columns[
-                ~datetime_df.apply(is_datetime)
-            ].tolist()
-            if non_dt_columns:
-                raise ValueError(
-                    "ValueError: variable(s) "
-                    + (len(non_dt_columns) * "{} ").format(*non_dt_columns)
-                    + "could not be converted to datetime. Try setting utc=True"
-                )
-
             # create new features
             for var in self.variables_:
                 for feat in self.features_to_extract_:
@@ -360,7 +377,7 @@ class DatetimeFeatures(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin)
         else:
             feature_names = [
                 str(var) + FEATURES_SUFFIXES[feat]
-                for var in self.variables_  # type: ignore
+                for var in self.variables_
                 for feat in self.features_to_extract_
             ]
 
@@ -377,3 +394,7 @@ class DatetimeFeatures(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin)
     def _more_tags(self):
         tags_dict = {"variables": "datetime"}
         return tags_dict
+
+    def __sklearn_tags__(self):
+        tags = super().__sklearn_tags__()
+        return tags
