@@ -7,7 +7,6 @@ from .decision_tree import DecisionTreeEncoder
 from .mean_encoding import MeanEncoder
 from .one_hot import OneHotEncoder
 from .ordinal import OrdinalEncoder
-from .probability_ratio import PRatioEncoder
 from .rare_label import RareLabelEncoder
 from .similarity_encoder import StringSimilarityEncoder
 from .woe import WoEEncoder
@@ -18,7 +17,6 @@ __all__ = [
     "MeanEncoder",
     "OneHotEncoder",
     "OrdinalEncoder",
-    "PRatioEncoder",
     "RareLabelEncoder",
     "StringSimilarityEncoder",
     "WoEEncoder",
