@@ -10,10 +10,13 @@ from feature_engine._docstrings.fit_attributes import (
     _n_features_in_docstring,
     _variables_attribute_docstring,
 )
-from feature_engine._docstrings.init_parameters import (
+from feature_engine._docstrings.init_parameters.all_trasnformers import (
+    _missing_values_docstring,
+    _variables_categorical_docstring,
+)
+from feature_engine._docstrings.init_parameters.encoders import (
     _ignore_format_docstring,
     _unseen_docstring,
-    _variables_categorical_docstring,
 )
 from feature_engine._docstrings.methods import (
     _fit_transform_docstring,
@@ -24,7 +27,7 @@ from feature_engine._docstrings.substitute import Substitution
 from feature_engine.dataframe_checks import check_X
 from feature_engine.encoding._helper_functions import check_parameter_unseen
 from feature_engine.encoding.base_encoder import (
-    CategoricalInitMixin,
+    CategoricalInitMixinNA,
     CategoricalMethodsMixin,
 )
 
@@ -36,6 +39,7 @@ _unseen_docstring = (
 
 @Substitution(
     ignore_format=_ignore_format_docstring,
+    missing_values=_missing_values_docstring,
     variables=_variables_categorical_docstring,
     unseen=_unseen_docstring,
     variables_=_variables_attribute_docstring,
@@ -45,7 +49,7 @@ _unseen_docstring = (
     transform=_transform_encoders_docstring,
     inverse_transform=_inverse_transform_docstring,
 )
-class CountFrequencyEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
+class CountFrequencyEncoder(CategoricalMethodsMixin, CategoricalInitMixinNA):
     """
     The CountFrequencyEncoder() replaces categories by either the count or the
     percentage of observations per category.
@@ -80,6 +84,8 @@ class CountFrequencyEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
 
     {variables}
 
+    {missing_values}
+
     {ignore_format}
 
     {unseen}
@@ -119,12 +125,37 @@ class CountFrequencyEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
     --------
     feature_engine.encoding.RareLabelEncoder
     category_encoders.count.CountEncoder
+
+    Examples
+    --------
+
+    >>> import pandas as pd
+    >>> from feature_engine.encoding import CountFrequencyEncoder
+    >>> X = pd.DataFrame(dict(x1 = [1,2,3,4], x2 = ["c", "a", "b", "c"]))
+    >>> cf = CountFrequencyEncoder(encoding_method='count')
+    >>> cf.fit(X)
+    >>> cf.transform(X)
+       x1  x2
+    0   1   2
+    1   2   1
+    2   3   1
+    3   4   2
+
+    >>> cf = CountFrequencyEncoder(encoding_method='frequency')
+    >>> cf.fit(X)
+    >>> cf.transform(X)
+       x1    x2
+    0   1  0.50
+    1   2  0.25
+    2   3  0.25
+    3   4  0.50
     """
 
     def __init__(
         self,
         encoding_method: str = "count",
         variables: Union[None, int, str, List[Union[str, int]]] = None,
+        missing_values: str = "raise",
         ignore_format: bool = False,
         unseen: str = "ignore",
     ) -> None:
@@ -136,7 +167,7 @@ class CountFrequencyEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
             )
 
         check_parameter_unseen(unseen, ["ignore", "raise", "encode"])
-        super().__init__(variables, ignore_format)
+        super().__init__(variables, missing_values, ignore_format)
         self.encoding_method = encoding_method
         self.unseen = unseen
 
@@ -154,21 +185,29 @@ class CountFrequencyEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
             y is not needed in this encoder. You can pass y or None.
         """
         X = check_X(X)
-        self._fit(X)
-        self._get_feature_names_in(X)
+        variables_ = self._check_or_select_variables(X)
+        self._check_na(X, variables_)
 
         self.encoder_dict_ = {}
 
         # learn encoding maps
-        for var in self.variables_:
+        for var in variables_:
             if self.encoding_method == "count":
                 self.encoder_dict_[var] = X[var].value_counts().to_dict()
 
             elif self.encoding_method == "frequency":
                 self.encoder_dict_[var] = X[var].value_counts(normalize=True).to_dict()
+            else:
+                raise ValueError(
+                    "Unrecognized value for encoding_method. It should be 'count' or "
+                    f"'frequency'. Got {self.encoding_method} instead."
+                )
 
         # unseen categories are replaced by 0
         if self.unseen == "encode":
             self._unseen = 0
 
+        # assign underscore parameters at the end in case code above fails
+        self.variables_ = variables_
+        self._get_feature_names_in(X)
         return self
