@@ -3,6 +3,7 @@
 
 from typing import List, Optional, Union
 
+import numpy as np
 import pandas as pd
 from sklearn.pipeline import Pipeline
 from sklearn.utils.multiclass import check_classification_targets, type_of_target
@@ -12,14 +13,21 @@ from feature_engine._docstrings.fit_attributes import (
     _n_features_in_docstring,
     _variables_attribute_docstring,
 )
-from feature_engine._docstrings.init_parameters import (
-    _ignore_format_docstring,
+from feature_engine._docstrings.init_parameters.all_trasnformers import (
     _variables_categorical_docstring,
 )
-from feature_engine._docstrings.methods import _fit_transform_docstring
+from feature_engine._docstrings.init_parameters.encoders import (
+    _ignore_format_docstring,
+    _unseen_docstring,
+)
+from feature_engine._docstrings.methods import (
+    _fit_transform_docstring,
+    _inverse_transform_docstring,
+)
 from feature_engine._docstrings.substitute import Substitution
-from feature_engine.dataframe_checks import check_X_y
+from feature_engine.dataframe_checks import _check_contains_na, check_X_y
 from feature_engine.discretisation import DecisionTreeDiscretiser
+from feature_engine.encoding._helper_functions import check_parameter_unseen
 from feature_engine.encoding.base_encoder import (
     CategoricalInitMixin,
     CategoricalMethodsMixin,
@@ -28,23 +36,31 @@ from feature_engine.encoding.ordinal import OrdinalEncoder
 from feature_engine.tags import _return_tags
 
 
+_unseen_docstring = (
+    _unseen_docstring
+    + """ If `'encode'` unseen categories will be encoded as `fill_value`."""
+)
+
+
 @Substitution(
     ignore_format=_ignore_format_docstring,
     variables=_variables_categorical_docstring,
     variables_=_variables_attribute_docstring,
+    unseen=_unseen_docstring,
     feature_names_in_=_feature_names_in_docstring,
     n_features_in_=_n_features_in_docstring,
     fit_transform=_fit_transform_docstring,
+    inverse_transform=_inverse_transform_docstring,
 )
-class DecisionTreeEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
+class DecisionTreeEncoder(CategoricalMethodsMixin, CategoricalInitMixin):
     """
-    The DecisionTreeEncoder() encodes categorical variables with predictions
+    The DecisionTreeEncoder() encodes categorical variables with the predictions
     of a decision tree.
 
-    The encoder first fits a decision tree using a single feature and the target (fit),
-    and then replaces the values of the original feature by the predictions of the
-    tree (transform). The transformer will train a decision tree per every feature to
-    encode.
+    The encoder fits a single feature decision tree to predict the target, and
+    with that, it creates mappings from category to prediction value. Then, it uses
+    these mappings to replace the categories of the feature. The encoder trains a
+    decision tree per feature to encode.
 
     The DecisionTreeEncoder() will encode only categorical variables by default
     (type 'object' or 'categorical'). You can pass a list of variables to encode or the
@@ -111,10 +127,19 @@ class DecisionTreeEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
 
     {ignore_format}
 
+    precision: int, default=None
+        The precision at which to store and display the category mappings. In other
+        words, the number of decimals after the comma for the tree predictions.
+
+    {unseen}
+
+    fill_value: float, default=None
+        The value used to encode unseen categories. Only used when `unseen='encode'`.
+
     Attributes
     ----------
-    encoder_:
-        sklearn Pipeline containing the ordinal encoder and the decision tree.
+    encoder_dict_:
+        Dictionary with the prediction per category, per variable.
 
     {variables_}
 
@@ -129,6 +154,8 @@ class DecisionTreeEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
 
     {fit_transform}
 
+    {inverse_transform}
+
     transform:
         Replace categorical variable by the predictions of the decision tree.
 
@@ -136,13 +163,9 @@ class DecisionTreeEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
     -----
     The authors designed this method originally to work with numerical variables. We
     can replace numerical variables by the predictions of a decision tree utilising the
-    DecisionTreeDiscretiser(). Here we extend this functionality to work also with
+    DecisionTreeDiscretiser(). Here, we extend this functionality to work also with
     categorical variables.
 
-    NAN are introduced when encoding categories that were not present in the training
-    dataset. If this happens, try grouping infrequent categories using the
-    RareLabelEncoder().
-
     See Also
     --------
     sklearn.ensemble.DecisionTreeRegressor
@@ -156,6 +179,36 @@ class DecisionTreeEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
     .. [1] Niculescu-Mizil, et al. "Winning the KDD Cup Orange Challenge with Ensemble
         Selection". JMLR: Workshop and Conference Proceedings 7: 23-34. KDD 2009
         http://proceedings.mlr.press/v7/niculescu09/niculescu09.pdf
+
+    Examples
+    --------
+
+    >>> import pandas as pd
+    >>> from feature_engine.encoding import DecisionTreeEncoder
+    >>> X = pd.DataFrame(dict(x1 = [1,2,3,4,5], x2 = ["b", "b", "b", "a", "a"]))
+    >>> y = pd.Series([2.2,4, 1.5, 3.2, 1.1])
+    >>> dte = DecisionTreeEncoder(cv=2)
+    >>> dte.fit(X, y)
+    >>> dte.transform(X)
+       x1        x2
+    0   1  2.566667
+    1   2  2.566667
+    2   3  2.566667
+    3   4  2.150000
+    4   5  2.150000
+
+    You can also use it for classification by using `regression=False`.
+
+    >>> y = pd.Series([0,1,1,1,0])
+    >>> dte = DecisionTreeEncoder(regression=False, cv=2)
+    >>> dte.fit(X, y)
+    >>> dte.transform(X)
+       x1        x2
+    0   1  0.666667
+    1   2  0.666667
+    2   3  0.666667
+    3   4  0.500000
+    4   5  0.500000
     """
 
     def __init__(
@@ -168,8 +221,32 @@ class DecisionTreeEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
         random_state: Optional[int] = None,
         variables: Union[None, int, str, List[Union[str, int]]] = None,
         ignore_format: bool = False,
+        precision: Optional[int] = None,
+        unseen: str = "ignore",
+        fill_value: Optional[float] = None,
     ) -> None:
 
+        if encoding_method not in ["ordered", "arbitrary"]:
+            raise ValueError(
+                "`encoding_method` takes only values 'ordered' and 'arbitrary'."
+                f" Got {encoding_method} instead."
+            )
+
+        if unseen == "encode" and (
+            fill_value is None or not isinstance(fill_value, (int, float))
+        ):
+            raise ValueError(
+                "When `unseen='encode'` you need to pass a number to `fill_value`. "
+                f"Got {fill_value} instead."
+            )
+
+        if precision is not None and (not isinstance(precision, int) or precision < 0):
+            raise ValueError(
+                "Parameter `precision` takes integers or None. "
+                f"Got {precision} instead."
+            )
+
+        check_parameter_unseen(unseen, ["ignore", "raise", "encode"])
         super().__init__(variables, ignore_format)
         self.encoding_method = encoding_method
         self.cv = cv
@@ -177,6 +254,9 @@ class DecisionTreeEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
         self.regression = regression
         self.param_grid = param_grid
         self.random_state = random_state
+        self.precision = precision
+        self.unseen = unseen
+        self.fill_value = fill_value
 
     def fit(self, X: pd.DataFrame, y: pd.Series):
         """
@@ -206,42 +286,51 @@ class DecisionTreeEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
         else:
             check_classification_targets(y)
 
-        self._fit(X)
-        self._get_feature_names_in(X)
+        variables_ = self._check_or_select_variables(X)
+        _check_contains_na(X, variables_)
 
-        if self.param_grid:
-            param_grid = self.param_grid
-        else:
-            param_grid = {"max_depth": [1, 2, 3, 4]}
+        param_grid = self._assign_param_grid()
 
-        # initialize categorical encoder
-        cat_encoder = OrdinalEncoder(
+        encoder = OrdinalEncoder(
             encoding_method=self.encoding_method,
-            variables=self.variables_,
+            variables=variables_,
+            missing_values="raise",
             ignore_format=self.ignore_format,
-            unseen="raise",
         )
 
-        # initialize decision tree discretiser
-        tree_discretiser = DecisionTreeDiscretiser(
+        tree = DecisionTreeDiscretiser(
             cv=self.cv,
             scoring=self.scoring,
-            variables=self.variables_,
+            variables=variables_,
             param_grid=param_grid,
             regression=self.regression,
             random_state=self.random_state,
         )
 
         # pipeline for the encoder
-        self.encoder_ = Pipeline(
+        pipe = Pipeline(
             [
-                ("categorical_encoder", cat_encoder),
-                ("tree_discretiser", tree_discretiser),
+                ("encoder", encoder),
+                ("tree", tree),
             ]
         )
 
-        self.encoder_.fit(X, y)
+        Xt = pipe.fit_transform(X, y)
 
+        encoder_ = {}
+        if self.precision is None:
+            for var in variables_:
+                encoder_[var] = dict(zip(X[var], Xt[var]))
+        else:
+            for var in variables_:
+                encoder_[var] = dict(zip(X[var], np.round(Xt[var], self.precision)))
+
+        if self.unseen == "encode":
+            self._unseen = self.fill_value
+
+        self.encoder_dict_ = encoder_
+        self.variables_ = variables_
+        self._get_feature_names_in(X)
         return self
 
     def transform(self, X: pd.DataFrame) -> pd.DataFrame:
@@ -258,18 +347,18 @@ class DecisionTreeEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
         X_new : pandas dataframe of shape = [n_samples, n_features].
             Dataframe with variables encoded with decision tree predictions.
         """
-
         X = self._check_transform_input_and_state(X)
-
-        X = self.encoder_.transform(X)
+        _check_contains_na(X, self.variables_)
+        X = self._encode(X)
 
         return X
 
-    def inverse_transform(self, X: pd.DataFrame):
-        """inverse_transform is not implemented for this transformer."""
-        raise NotImplementedError(
-            "inverse_transform is not implemented for this transformer."
-        )
+    def _assign_param_grid(self):
+        if self.param_grid:
+            param_grid = self.param_grid
+        else:
+            param_grid = {"max_depth": [1, 2, 3, 4]}
+        return param_grid
 
     def _more_tags(self):
         tags_dict = _return_tags()
