@@ -9,10 +9,13 @@ from feature_engine._docstrings.fit_attributes import (
     _n_features_in_docstring,
     _variables_attribute_docstring,
 )
-from feature_engine._docstrings.init_parameters import (
+from feature_engine._docstrings.init_parameters.all_trasnformers import (
+    _missing_values_docstring,
+    _variables_categorical_docstring,
+)
+from feature_engine._docstrings.init_parameters.encoders import (
     _ignore_format_docstring,
     _unseen_docstring,
-    _variables_categorical_docstring,
 )
 from feature_engine._docstrings.methods import (
     _fit_transform_docstring,
@@ -20,14 +23,13 @@ from feature_engine._docstrings.methods import (
     _transform_encoders_docstring,
 )
 from feature_engine._docstrings.substitute import Substitution
-from feature_engine.encoding._helper_functions import check_parameter_unseen
 from feature_engine.dataframe_checks import check_X_y
+from feature_engine.encoding._helper_functions import check_parameter_unseen
 from feature_engine.encoding.base_encoder import (
-    CategoricalInitMixin,
+    CategoricalInitMixinNA,
     CategoricalMethodsMixin,
 )
 
-
 _unseen_docstring = (
     _unseen_docstring
     + """ If `'encode'`, unseen categories will be encoded with the prior."""
@@ -35,6 +37,7 @@ _unseen_docstring = (
 
 
 @Substitution(
+    missing_values=_missing_values_docstring,
     ignore_format=_ignore_format_docstring,
     variables=_variables_categorical_docstring,
     unseen=_unseen_docstring,
@@ -45,7 +48,7 @@ _unseen_docstring = (
     transform=_transform_encoders_docstring,
     inverse_transform=_inverse_transform_docstring,
 )
-class MeanEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
+class MeanEncoder(CategoricalMethodsMixin, CategoricalInitMixinNA):
     """
     The MeanEncoder() replaces categories by the mean value of the target for each
     category.
@@ -92,6 +95,8 @@ class MeanEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
     ----------
     {variables}
 
+    {missing_values}
+
     {ignore_format}
 
     {unseen}
@@ -146,16 +151,34 @@ class MeanEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
     .. [1] Micci-Barreca D. "A Preprocessing Scheme for High-Cardinality Categorical
        Attributes in Classification and Prediction Problems". ACM SIGKDD Explorations
        Newsletter, 2001. https://dl.acm.org/citation.cfm?id=507538
+
+    Examples
+    --------
+
+    >>> import pandas as pd
+    >>> from feature_engine.encoding import MeanEncoder
+    >>> X = pd.DataFrame(dict(x1 = [1,2,3,4,5], x2 = ["c", "c", "c", "b", "a"]))
+    >>> y = pd.Series([0,1,1,1,0])
+    >>> me = MeanEncoder()
+    >>> me.fit(X,y)
+    >>> me.transform(X)
+       x1        x2
+    0   1  0.666667
+    1   2  0.666667
+    2   3  0.666667
+    3   4  1.000000
+    4   5  0.000000
     """
 
     def __init__(
         self,
         variables: Union[None, int, str, List[Union[str, int]]] = None,
+        missing_values: str = "raise",
         ignore_format: bool = False,
         unseen: str = "ignore",
         smoothing: Union[int, float, str] = 0.0,
     ) -> None:
-        super().__init__(variables, ignore_format)
+        super().__init__(variables, missing_values, ignore_format)
         if (
             not isinstance(smoothing, (str, float, int))
             or isinstance(smoothing, str)
@@ -184,8 +207,8 @@ class MeanEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
         """
 
         X, y = check_X_y(X, y)
-        self._fit(X)
-        self._get_feature_names_in(X)
+        variables_ = self._check_or_select_variables(X)
+        self._check_na(X, variables_)
 
         self.encoder_dict_ = {}
 
@@ -196,17 +219,22 @@ class MeanEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
 
         if self.smoothing == "auto":
             y_var = y.var(ddof=0)
-        for var in self.variables_:
+        for var in variables_:
             if self.smoothing == "auto":
                 damping = y.groupby(X[var]).var(ddof=0) / y_var
             else:
                 damping = self.smoothing
             counts = X[var].value_counts()
+            counts.index = counts.index.infer_objects()
             _lambda = counts / (counts + damping)
             self.encoder_dict_[var] = (
-                _lambda * y.groupby(X[var]).mean() + (1.0 - _lambda) * y_prior
+                _lambda * y.groupby(X[var], observed=False).mean()
+                + (1.0 - _lambda) * y_prior
             ).to_dict()
 
+        # assign underscore parameters at the end in case code above fails
+        self.variables_ = variables_
+        self._get_feature_names_in(X)
         return self
 
     def inverse_transform(self, X: pd.DataFrame) -> pd.DataFrame:
@@ -228,7 +256,8 @@ class MeanEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
 
         if self.unseen == "encode":
             raise NotImplementedError(
-                "inverse_transform is not implemented for this transformer."
+                "inverse_transform is not implemented for this transformer when "
+                "`unseen='encode'`."
             )
         else:
             return super().inverse_transform(X)
@@ -237,3 +266,7 @@ class MeanEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
         tags_dict = super()._more_tags()
         tags_dict["requires_y"] = True
         return tags_dict
+
+    def __sklearn_tags__(self):
+        tags = super().__sklearn_tags__()
+        return tags
