@@ -2,27 +2,14 @@ import pandas as pd
 from sklearn.base import BaseEstimator, TransformerMixin
 from sklearn.utils.validation import check_is_fitted
 
-from feature_engine.dataframe_checks import _check_X_matches_training_df, check_X
 from feature_engine._base_transformers.mixins import GetFeatureNamesOutMixin
+from feature_engine.dataframe_checks import _check_X_matches_training_df, check_X
 from feature_engine.tags import _return_tags
 
 
-class BaseImputer(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin):
+class BaseImputer(TransformerMixin, BaseEstimator, GetFeatureNamesOutMixin):
     """shared set-up checks and methods across imputers"""
 
-    _variables_numerical_docstring = """variables: list, default=None
-        The list of variables to impute. If None, the imputer will select
-        all numerical variables.
-        """.rstrip()
-
-    _imputer_dict_docstring = """imputer_dict_:
-        Dictionary with the values to replace missing data in each variable.
-        """.rstrip()
-
-    _transform_docstring = """transform:
-        Impute missing data.
-        """.rstrip()
-
     def _transform(self, X: pd.DataFrame) -> pd.DataFrame:
         """
         Common checks before transforming data:
@@ -73,8 +60,8 @@ class BaseImputer(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin):
         X = self._transform(X)
 
         # Replace missing data with learned parameters
-        X.fillna(value=self.imputer_dict_, inplace=True)
-
+        with pd.option_context("future.no_silent_downcasting", True):
+            X = X.fillna(value=self.imputer_dict_).infer_objects(copy=False)
         return X
 
     def _get_feature_names_in(self, X):
@@ -91,3 +78,8 @@ class BaseImputer(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin):
         tags_dict["allow_nan"] = True
         tags_dict["variables"] = "numerical"
         return tags_dict
+
+    def __sklearn_tags__(self):
+        tags = super().__sklearn_tags__()
+        tags.input_tags.allow_nan = True
+        return tags
