@@ -5,30 +5,38 @@ from typing import List, Optional, Union
 
 import pandas as pd
 
+from feature_engine._check_init_parameters.check_variables import (
+    _check_variables_input_value,
+)
 from feature_engine._docstrings.fit_attributes import (
     _feature_names_in_docstring,
+    _imputer_dict_docstring,
     _n_features_in_docstring,
     _variables_attribute_docstring,
 )
-from feature_engine._docstrings.methods import _fit_transform_docstring
+from feature_engine._docstrings.init_parameters.all_trasnformers import (
+    _variables_numerical_docstring,
+)
+from feature_engine._docstrings.methods import (
+    _fit_transform_docstring,
+    _transform_imputers_docstring,
+)
 from feature_engine._docstrings.substitute import Substitution
-from feature_engine._variable_handling.init_parameter_checks import (
-    _check_init_parameter_variables,
-)
-from feature_engine._variable_handling.variable_type_selection import (
-    _find_or_check_numerical_variables,
-)
 from feature_engine.dataframe_checks import check_X
 from feature_engine.imputation.base_imputer import BaseImputer
+from feature_engine.variable_handling import (
+    check_numerical_variables,
+    find_numerical_variables,
+)
 
 
 @Substitution(
-    variables=BaseImputer._variables_numerical_docstring,
-    imputer_dict_=BaseImputer._imputer_dict_docstring,
+    variables=_variables_numerical_docstring,
+    imputer_dict_=_imputer_dict_docstring,
     variables_=_variables_attribute_docstring,
     feature_names_in_=_feature_names_in_docstring,
     n_features_in_=_n_features_in_docstring,
-    transform=BaseImputer._transform_docstring,
+    transform=_transform_imputers_docstring,
     fit_transform=_fit_transform_docstring,
 )
 class EndTailImputer(BaseImputer):
@@ -110,6 +118,22 @@ class EndTailImputer(BaseImputer):
 
     {transform}
 
+    Examples
+    --------
+
+    >>> import pandas as pd
+    >>> import numpy as np
+    >>> from feature_engine.imputation import EndTailImputer
+    >>> X = pd.DataFrame(dict(x1 = [np.nan,0.5, 0.5, 0,np.nan]))
+    >>> eti = EndTailImputer(imputation_method='gaussian', tail='right', fold=3)
+    >>> eti.fit(X)
+    >>> eti.transform(X)
+             x1
+    0  1.199359
+    1  0.500000
+    2  0.500000
+    3  0.000000
+    4  1.199359
     """
 
     def __init__(
@@ -134,7 +158,7 @@ class EndTailImputer(BaseImputer):
         self.imputation_method = imputation_method
         self.tail = tail
         self.fold = fold
-        self.variables = _check_init_parameter_variables(variables)
+        self.variables = _check_variables_input_value(variables)
 
     def fit(self, X: pd.DataFrame, y: Optional[pd.Series] = None):
         """
@@ -152,7 +176,10 @@ class EndTailImputer(BaseImputer):
         X = check_X(X)
 
         # find or check for numerical variables
-        self.variables_ = _find_or_check_numerical_variables(X, self.variables)
+        if self.variables is None:
+            self.variables_ = find_numerical_variables(X)
+        else:
+            self.variables_ = check_numerical_variables(X, self.variables)
 
         # estimate imputation values
         if self.imputation_method == "max":
