@@ -5,21 +5,19 @@ from typing import List, Optional, Union
 
 import pandas as pd
 
+from feature_engine._check_init_parameters.check_variables import (
+    _check_variables_input_value,
+)
 from feature_engine._docstrings.fit_attributes import (
     _feature_names_in_docstring,
     _n_features_in_docstring,
 )
 from feature_engine._docstrings.methods import _fit_transform_docstring
 from feature_engine._docstrings.substitute import Substitution
-from feature_engine._variable_handling.init_parameter_checks import (
-    _check_init_parameter_variables,
-)
-from feature_engine._variable_handling.variable_type_selection import (
-    _find_all_variables,
-)
 from feature_engine.dataframe_checks import check_X
 from feature_engine.imputation.base_imputer import BaseImputer
 from feature_engine.tags import _return_tags
+from feature_engine.variable_handling import check_all_variables, find_all_variables
 
 
 @Substitution(
@@ -80,6 +78,25 @@ class AddMissingIndicator(BaseImputer):
     transform:
         Add the missing indicators.
 
+    Examples
+    --------
+
+    >>> import pandas as pd
+    >>> import numpy as np
+    >>> from feature_engine.imputation import AddMissingIndicator
+    >>> X = pd.DataFrame(dict(
+    >>>        x1 = [np.nan,1,1,0,np.nan],
+    >>>        x2 = ["a", np.nan, "b", np.nan, "a"],
+    >>>        ))
+    >>> ami = AddMissingIndicator()
+    >>> ami.fit(X)
+    >>> ami.transform(X)
+        x1   x2  x1_na  x2_na
+    0  NaN    a      1      0
+    1  1.0  NaN      0      1
+    2  1.0    b      0      0
+    3  0.0  NaN      0      1
+    4  NaN    a      1      0
     """
 
     def __init__(
@@ -91,7 +108,7 @@ class AddMissingIndicator(BaseImputer):
         if not isinstance(missing_only, bool):
             raise ValueError("missing_only takes values True or False")
 
-        self.variables = _check_init_parameter_variables(variables)
+        self.variables = _check_variables_input_value(variables)
         self.missing_only = missing_only
 
     def fit(self, X: pd.DataFrame, y: Optional[pd.Series] = None):
@@ -111,7 +128,10 @@ class AddMissingIndicator(BaseImputer):
         X = check_X(X)
 
         # find variables for which indicator should be added
-        self.variables_ = _find_all_variables(X, self.variables)
+        if self.variables is None:
+            self.variables_ = find_all_variables(X)
+        else:
+            self.variables_ = check_all_variables(X, self.variables)
 
         if self.missing_only is True:
             self.variables_ = [
@@ -159,3 +179,8 @@ class AddMissingIndicator(BaseImputer):
         tags_dict["allow_nan"] = True
         tags_dict["variables"] = "all"
         return tags_dict
+
+    def __sklearn_tags__(self):
+        tags = super().__sklearn_tags__()
+        tags.input_tags.allow_nan = True
+        return tags
