@@ -1,14 +1,12 @@
-from typing import List, Optional, Union
+from typing import List, Literal, Optional, Union
 
 import pandas as pd
 from sklearn.base import BaseEstimator, TransformerMixin
 from sklearn.utils.validation import check_is_fitted
 
-from feature_engine._variable_handling.init_parameter_checks import (
-    _check_init_parameter_variables,
-)
-from feature_engine._variable_handling.variable_type_selection import (
-    _find_or_check_numerical_variables,
+from feature_engine._base_transformers.mixins import GetFeatureNamesOutMixin
+from feature_engine._check_init_parameters.check_variables import (
+    _check_variables_input_value,
 )
 from feature_engine.dataframe_checks import (
     _check_contains_inf,
@@ -16,23 +14,16 @@ from feature_engine.dataframe_checks import (
     _check_X_matches_training_df,
     check_X,
 )
-from feature_engine._base_transformers.mixins import GetFeatureNamesOutMixin
 from feature_engine.tags import _return_tags
+from feature_engine.variable_handling import (
+    check_numerical_variables,
+    find_numerical_variables,
+)
 
 
-class BaseOutlier(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin):
+class BaseOutlier(TransformerMixin, BaseEstimator, GetFeatureNamesOutMixin):
     """shared set-up checks and methods across outlier transformers"""
 
-    _right_tail_caps_docstring = """right_tail_caps_:
-        Dictionary with the maximum values beyond which a value will be considered an
-        outlier.
-        """.rstrip()
-
-    _left_tail_caps_docstring = """left_tail_caps_:
-        Dictionary with the minimum values beyond which a value will be considered an
-        outlier.
-        """.rstrip()
-
     def _check_transform_input_and_state(self, X: pd.DataFrame) -> pd.DataFrame:
         """Checks that the input is a dataframe and of the same size than the one used
         in the fit method. Checks absence of NA.
@@ -73,7 +64,7 @@ class BaseOutlier(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin):
 
         return X
 
-    def transform(self, X: pd.DataFrame) -> pd.DataFrame:
+    def _transform(self, X: pd.DataFrame) -> pd.DataFrame:
         """
         Cap the variable values.
 
@@ -105,6 +96,10 @@ class BaseOutlier(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin):
         tags_dict["variables"] = "numerical"
         return tags_dict
 
+    def __sklearn_tags__(self):
+        tags = super().__sklearn_tags__()
+        return tags
+
 
 class WinsorizerBase(BaseOutlier):
 
@@ -123,15 +118,15 @@ class WinsorizerBase(BaseOutlier):
 
     **IQR limits:**
 
-    - right tail: 75th quantile + 3* IQR
-    - left tail:  25th quantile - 3* IQR
+    - right tail: 75th quantile + 1.5* IQR
+    - left tail:  25th quantile - 1.5* IQR
 
     where IQR is the inter-quartile range: 75th quantile - 25th quantile.
 
     **MAD limits:**
 
-    - right tail: median + 3* MAD
-    - left tail:  median - 3* MAD
+    - right tail: median + 3.29* MAD
+    - left tail:  median - 3.29* MAD
 
     where MAD is the median absoulte deviation from the median.
 
@@ -154,69 +149,53 @@ class WinsorizerBase(BaseOutlier):
     percentiles. If fold=0.1, the limits will be the 10th and 90th percentiles.
     """.rstrip()
 
-    _capping_method_docstring = """capping_method: str, default='gaussian'
-        Desired outlier detection method. Can be 'gaussian', 'iqr', 'mad', 'quantiles'.
-
-        The transformer will find the maximum and / or minimum values beyond which a
-        data point will be considered an outlier using:
-        **'gaussian'**: the Gaussian approximation.
-        **'iqr'**: the IQR proximity rule.
-        **'quantiles'**: the percentiles.
-        **'mad'**: the Gaussian approximation but using robust statistics.
-        """.rstrip()
-
-    _tail_docstring = """tail: str, default='right'
-        Whether to look for outliers on the right, left or both tails of the
-        distribution. Can take 'left', 'right' or 'both'.
-        """.rstrip()
-
-    _fold_docstring = """fold: int or float, default=3
-        The factor used to multiply the std, MAD or IQR to calculate
-        the maximum or minimum allowed values.
-        Recommended values are 2 or 3 for the gaussian approximation,
-        1.5 or 3 for the IQR proximity rule and 3 or 3.5 for MAD rule.
-
-        If `capping_method='quantile'`, then `'fold'` indicates the percentile. So if
-        `fold=0.05`, the limits will be the 95th and 5th percentiles.
-
-        **Note**: Outliers will be removed up to a maximum of the 20th percentiles on
-        both sides. Thus, when `capping_method='quantile'`, then `'fold'` takes values
-        between 0 and 0.20.
-        """.rstrip()
-
     def __init__(
         self,
         capping_method: str = "gaussian",
         tail: str = "right",
-        fold: Union[int, float] = 3,
+        fold: Union[int, float, Literal["auto"]] = "auto",
         variables: Union[None, int, str, List[Union[str, int]]] = None,
         missing_values: str = "raise",
     ) -> None:
 
-        if capping_method not in ["gaussian", "iqr", "quantiles", "mad"]:
+        if capping_method not in ("gaussian", "iqr", "quantiles", "mad"):
             raise ValueError(
-                "capping_method takes only values 'gaussian', 'iqr', 'mad', 'quantiles'"
+                f"capping_method must be 'gaussian', 'iqr', 'mad', 'quantiles'."
+                f" Got {capping_method} instead."
             )
 
-        if tail not in ["right", "left", "both"]:
-            raise ValueError("tail takes only values 'right', 'left' or 'both'")
+        if tail not in ("right", "left", "both"):
+            raise ValueError(
+                f"tail must be 'right', 'left' or 'both'. Got {tail} instead."
+            )
 
-        if fold <= 0:
-            raise ValueError("fold takes only positive numbers")
+        if (isinstance(fold, str) and (fold != "auto")) or (
+            isinstance(fold, (int, float)) and (fold <= 0)
+        ):
+            raise ValueError(
+                f"fold must be a positive number or 'auto'. Got {fold} instead."
+            )
 
-        if capping_method == "quantiles" and fold > 0.2:
+        if (
+            capping_method == "quantiles"
+            and isinstance(fold, (int, float))
+            and fold > 0.2
+        ):
             raise ValueError(
                 "with capping_method ='quantiles', fold takes values between 0 and "
                 "0.20 only."
             )
 
-        if missing_values not in ["raise", "ignore"]:
-            raise ValueError("missing_values takes only values 'raise' or 'ignore'")
+        if missing_values not in ("raise", "ignore"):
+            raise ValueError(
+                f"missing_values must be 'raise' or 'ignore'."
+                f" Got {missing_values} instead."
+            )
 
         self.capping_method = capping_method
         self.tail = tail
         self.fold = fold
-        self.variables = _check_init_parameter_variables(variables)
+        self.variables = _check_variables_input_value(variables)
         self.missing_values = missing_values
 
     def fit(self, X: pd.DataFrame, y: Optional[pd.Series] = None):
@@ -236,7 +215,10 @@ class WinsorizerBase(BaseOutlier):
         X = check_X(X)
 
         # find or check for numerical variables
-        self.variables_ = _find_or_check_numerical_variables(X, self.variables)
+        if self.variables is None:
+            self.variables_ = find_numerical_variables(X)
+        else:
+            self.variables_ = check_numerical_variables(X, self.variables)
 
         if self.missing_values == "raise":
             # check if dataset contains na
@@ -246,6 +228,11 @@ class WinsorizerBase(BaseOutlier):
         self.right_tail_caps_ = {}
         self.left_tail_caps_ = {}
 
+        if self.fold == "auto":
+            self.fold_ = self._calculate_fold()
+        else:
+            self.fold_ = self.fold
+
         if self.capping_method == "gaussian":
             bias = X[self.variables_].mean()
             scale = X[self.variables_].std(ddof=0)
@@ -253,8 +240,8 @@ class WinsorizerBase(BaseOutlier):
             bias = X[self.variables_].quantile((0.75, 0.25))
             scale = bias.loc[0.75] - bias.loc[0.25]
         elif self.capping_method == "quantiles":
-            bias = X[self.variables_].quantile((1 - self.fold, self.fold))
-            scale = bias.loc[1 - self.fold] - bias.loc[self.fold]
+            bias = X[self.variables_].quantile((1 - self.fold_, self.fold_))
+            scale = bias.loc[1 - self.fold_] - bias.loc[self.fold_]
         elif self.capping_method == "mad":
             bias = X[self.variables_].median()
             # scaling factor for normal distribution
@@ -267,36 +254,46 @@ class WinsorizerBase(BaseOutlier):
             )
 
         # estimate the end values
-        if self.tail in ["right", "both"]:
+        if self.tail in ("right", "both"):
             if self.capping_method in ("gaussian", "mad"):
-                self.right_tail_caps_ = (bias + self.fold * scale).to_dict()
+                self.right_tail_caps_ = (bias + self.fold_ * scale).to_dict()
 
             elif self.capping_method == "iqr":
-                self.right_tail_caps_ = (bias.loc[0.75] + self.fold * scale).to_dict()
+                self.right_tail_caps_ = (bias.loc[0.75] + self.fold_ * scale).to_dict()
 
             elif self.capping_method == "quantiles":
-                self.right_tail_caps_ = bias.loc[1 - self.fold].to_dict()
+                self.right_tail_caps_ = bias.loc[1 - self.fold_].to_dict()
 
-        if self.tail in ["left", "both"]:
+        if self.tail in ("left", "both"):
             if self.capping_method in ("gaussian", "mad"):
-                self.left_tail_caps_ = (bias - self.fold * scale).to_dict()
+                self.left_tail_caps_ = (bias - self.fold_ * scale).to_dict()
 
             elif self.capping_method == "iqr":
-                self.left_tail_caps_ = (bias.loc[0.25] - self.fold * scale).to_dict()
+                self.left_tail_caps_ = (bias.loc[0.25] - self.fold_ * scale).to_dict()
 
             elif self.capping_method == "quantiles":
-                self.left_tail_caps_ = bias.loc[self.fold].to_dict()
+                self.left_tail_caps_ = bias.loc[self.fold_].to_dict()
 
         self.feature_names_in_ = X.columns.to_list()
         self.n_features_in_ = X.shape[1]
 
         return self
 
+    def _calculate_fold(self) -> float:
+        if self.capping_method == "quantiles":
+            return 0.05
+        elif self.capping_method == "iqr":
+            return 1.5
+        elif self.capping_method == "mad":
+            return 3.29
+        else:
+            return 3.0
+
     def _more_tags(self):
         tags_dict = _return_tags()
         tags_dict["variables"] = "numerical"
         # =======  this tests fail because the transformers throw an error
-        # when variance of the any input feature is 0.
+        # when variance of any input feature is 0.
         # Nothing to do with the test itself but
         # mostly with the data created and used in the test
         msg = (
@@ -305,3 +302,7 @@ class WinsorizerBase(BaseOutlier):
         )
         tags_dict["_xfail_checks"]["check_fit2d_1sample"] = msg
         return tags_dict
+
+    def __sklearn_tags__(self):
+        tags = super().__sklearn_tags__()
+        return tags
