@@ -1,16 +1,16 @@
-from typing import List, Union
+from typing import Dict, List, Union
 
 import numpy as np
 import pandas as pd
 from sklearn.base import BaseEstimator, TransformerMixin
 from sklearn.utils.validation import check_is_fitted
 
+from feature_engine._base_transformers.mixins import GetFeatureNamesOutMixin
 from feature_engine.dataframe_checks import _check_contains_na, check_X
 from feature_engine.tags import _return_tags
-from feature_engine._base_transformers.mixins import GetFeatureNamesOutMixin
 
 
-class MatchVariables(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin):
+class MatchVariables(TransformerMixin, BaseEstimator, GetFeatureNamesOutMixin):
     """
     MatchVariables() ensures that the same variables observed in the train set
     are present in the test set. If the dataset to transform contains variables that
@@ -63,12 +63,16 @@ class MatchVariables(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin):
     fill_value: integer, float or string. Default=np.nan
         The values for the variables that will be added to the transformed dataset.
 
-    missing_values: string, default='ignore'
+    missing_values: string, default='raise'
         Indicates if missing values should be ignored or raised. If 'raise' the
-        transformer will return an error if the the datasets to `fit` or `transform`
+        transformer will return an error if the datasets to `fit` or `transform`
         contain missing values. If 'ignore', missing data will be ignored when learning
         parameters or performing the transformation.
 
+    match_dtypes: bool, default=False
+        Indicates whether the dtypes observed in the train set should be applied to
+        variables in the test set.
+
     verbose: bool, default=True
         If True, the transformer will print out the names of the variables that are
         added and / or removed from the dataset.
@@ -81,6 +85,10 @@ class MatchVariables(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin):
     n_features_in_:
         The number of features in the train set used in fit.
 
+    dtype_dict_:
+        If `match_dtypes` is set to `True`, then this attribute will exist, and it will
+        contain a dictionary of variables and their corresponding dtypes.
+
     Methods
     -------
     fit:
@@ -100,21 +108,71 @@ class MatchVariables(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin):
 
     transform:
         Add or delete variables to match those observed in the train set.
+
+    Examples
+    --------
+
+    >>> import pandas as pd
+    >>> from feature_engine.preprocessing import MatchVariables
+    >>> X_train = pd.DataFrame(dict(x1 = ["a","b","c"], x2 = [4,5,6]))
+    >>> X_test = pd.DataFrame(dict(x1 = ["c","b","a","d"],
+    >>>                             x2 = [5,6,4,7],
+    >>>                             x3 = [1,1,1,1]))
+    >>> mv = MatchVariables(missing_values="ignore")
+    >>> mv.fit(X_train)
+    >>> mv.transform(X_train)
+    x1  x2
+    0  a   4
+    1  b   5
+    2  c   6
+    >>> mv.transform(X_test)
+    The following variables are dropped from the DataFrame: ['x3']
+      x1  x2
+    0  c   5
+    1  b   6
+    2  a   4
+    3  d   7
+
+    >>> import pandas as pd
+    >>> from feature_engine.preprocessing import MatchVariables
+    >>> X_train = pd.DataFrame(dict(x1 = ["a","b","c"],
+    >>>                             x2 = [4,5,6], x3 = [1,1,1]))
+    >>> X_test = pd.DataFrame(dict(x1 = ["c","b","a","d"], x2 = [5,6,4,7]))
+    >>> mv = MatchVariables(missing_values="ignore")
+    >>> mv.fit(X_train)
+    >>> mv.transform(X_train)
+      x1  x2  x3
+    0  a   4   1
+    1  b   5   1
+    2  c   6   1
+    >>> mv.transform(X_test)
+    The following variables are added to the DataFrame: ['x3']
+      x1  x2  x3
+    0  c   5 NaN
+    1  b   6 NaN
+    2  a   4 NaN
+    3  d   7 NaN
     """
 
     def __init__(
         self,
         fill_value: Union[str, int, float] = np.nan,
         missing_values: str = "raise",
+        match_dtypes: bool = False,
         verbose: bool = True,
     ):
-
         if missing_values not in ["raise", "ignore"]:
             raise ValueError(
                 "missing_values takes only values 'raise' or 'ignore'."
                 f"Got '{missing_values} instead."
             )
 
+        if not isinstance(match_dtypes, bool):
+            raise ValueError(
+                "match_dtypes takes only booleans True and False. "
+                f"Got '{match_dtypes} instead."
+            )
+
         if not isinstance(verbose, bool):
             raise ValueError(
                 "verbose takes only booleans True and False." f"Got '{verbose} instead."
@@ -129,6 +187,7 @@ class MatchVariables(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin):
 
         self.fill_value = fill_value
         self.missing_values = missing_values
+        self.match_dtypes = match_dtypes
         self.verbose = verbose
 
     def fit(self, X: pd.DataFrame, y: pd.Series = None):
@@ -154,6 +213,9 @@ class MatchVariables(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin):
 
         self.n_features_in_ = X.shape[1]
 
+        if self.match_dtypes:
+            self.dtype_dict_: Dict = X.dtypes.to_dict()
+
         return self
 
     def transform(self, X: pd.DataFrame) -> pd.DataFrame:
@@ -177,8 +239,11 @@ class MatchVariables(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin):
         X = check_X(X)
 
         if self.missing_values == "raise":
-            # check if dataset contains na
-            _check_contains_na(X, self.feature_names_in_)
+            # Some variables from the train set may not be present in the test set
+            # and vice versa. We'll check for nan only in the variables seen during
+            # training.
+            vars = [var for var in self.feature_names_in_ if var in X.columns]
+            _check_contains_na(X, vars)
 
         _columns_to_drop = list(set(X.columns) - set(self.feature_names_in_))
         _columns_to_add = list(set(self.feature_names_in_) - set(X.columns))
@@ -199,6 +264,23 @@ class MatchVariables(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin):
 
         X = X.reindex(columns=self.feature_names_in_, fill_value=self.fill_value)
 
+        if self.match_dtypes:
+            _current_dtypes = X.dtypes.to_dict()
+            _columns_to_update = {
+                column: new_dtype
+                for column, new_dtype in self.dtype_dict_.items()
+                if new_dtype != _current_dtypes[column]
+            }
+
+            if self.verbose:
+                for column, new_dtype in _columns_to_update.items():
+                    print(
+                        f"The {column} dtype is changing from ",
+                        f"{_current_dtypes[column]} to {new_dtype}",
+                    )
+
+            X = X.astype(_columns_to_update)
+
         return X
 
     # for the check_estimator tests
@@ -215,3 +297,7 @@ class MatchVariables(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin):
         tags_dict["_xfail_checks"]["check_estimators_nan_inf"] = msg
 
         return tags_dict
+
+    def __sklearn_tags__(self):
+        tags = super().__sklearn_tags__()
+        return tags
