@@ -6,13 +6,15 @@ from .drop_correlated_features import DropCorrelatedFeatures
 from .drop_duplicate_features import DropDuplicateFeatures
 from .drop_features import DropFeatures
 from .drop_psi_features import DropHighPSIFeatures
+from .information_value import SelectByInformationValue
+from .probe_feature_selection import ProbeFeatureSelection
 from .recursive_feature_addition import RecursiveFeatureAddition
 from .recursive_feature_elimination import RecursiveFeatureElimination
 from .shuffle_features import SelectByShuffling
 from .single_feature_performance import SelectBySingleFeaturePerformance
 from .smart_correlation_selection import SmartCorrelatedSelection
 from .target_mean_selection import SelectByTargetMeanPerformance
-from .information_value import SelectByInformationValue
+from .mrmr import MRMR
 
 __all__ = [
     "DropFeatures",
@@ -27,4 +29,6 @@ __all__ = [
     "RecursiveFeatureElimination",
     "SelectByTargetMeanPerformance",
     "SelectByInformationValue",
+    "ProbeFeatureSelection",
+    "MRMR",
 ]
