@@ -1,17 +1,21 @@
+from types import GeneratorType
 from typing import List, Union
 
 import pandas as pd
 from sklearn.model_selection import cross_validate
 
-from feature_engine._variable_handling.init_parameter_checks import (
-    _check_init_parameter_variables,
-)
-from feature_engine._variable_handling.variable_type_selection import (
-    _find_or_check_numerical_variables,
+from feature_engine._check_init_parameters.check_variables import (
+    _check_variables_input_value,
 )
 from feature_engine.dataframe_checks import check_X_y
-from feature_engine.selection.base_selector import BaseSelector, get_feature_importances
+from feature_engine.selection.base_selection_functions import get_feature_importances
+from feature_engine.selection.base_selector import BaseSelector
 from feature_engine.tags import _return_tags
+from feature_engine.variable_handling import (
+    check_numerical_variables,
+    find_numerical_variables,
+    retain_variables_if_in_df,
+)
 
 Variables = Union[None, int, str, List[Union[str, int]]]
 
@@ -62,6 +66,11 @@ class BaseRecursiveSelector(BaseSelector):
         across calls. For more details check Scikit-learn's `cross_validate`'s
         documentation.
 
+    groups: Array-like of shape (n_samples,), default=None
+        Group labels for the samples used while splitting
+        the dataset into train/test set. Only used in conjunction with a
+        “Group” cv instance (e.g., GroupKFold).
+
     confirm_variables: bool, default=False
         If set to True, variables that are not present in the input dataframe will be
         removed from the list of variables. Only used when passing a variable list to
@@ -75,8 +84,8 @@ class BaseRecursiveSelector(BaseSelector):
     feature_importances_:
         Pandas Series with the feature importance (comes from step 2)
 
-    performance_drifts_:
-        Dictionary with the performance drift per examined feature (comes from step 5).
+    feature_importances_std_:
+        Pandas Series with the standard deviation of the feature importance.
 
     features_to_drop_:
         List with the features to remove from the dataset.
@@ -96,25 +105,12 @@ class BaseRecursiveSelector(BaseSelector):
         Find the important features.
     """
 
-    _estimator_docstring = """estimator: object
-        A Scikit-learn estimator for regression or classification.
-        The estimator must have either a `feature_importances` or a `coef_` attribute
-        after fitting.
-        """.rstrip()
-
-    _feature_importances_docstring = """feature_importances_:
-        Pandas Series with the feature importance (comes from step 2)
-        """.rstrip()
-
-    _performance_drifts_docstring = """performance_drifts_:
-        Dictionary with the performance drift per examined feature (comes from step 5).
-        """.rstrip()
-
     def __init__(
         self,
         estimator,
         scoring: str = "roc_auc",
         cv=3,
+        groups=None,
         threshold: Union[int, float] = 0.01,
         variables: Variables = None,
         confirm_variables: bool = False,
@@ -124,11 +120,12 @@ class BaseRecursiveSelector(BaseSelector):
             raise ValueError("threshold can only be integer or float")
 
         super().__init__(confirm_variables)
-        self.variables = _check_init_parameter_variables(variables)
+        self.variables = _check_variables_input_value(variables)
         self.estimator = estimator
         self.scoring = scoring
         self.threshold = threshold
         self.cv = cv
+        self.groups = groups
 
     def fit(self, X: pd.DataFrame, y: pd.Series):
         """
@@ -146,11 +143,16 @@ class BaseRecursiveSelector(BaseSelector):
         # check input dataframe
         X, y = check_X_y(X, y)
 
-        # If required exclude variables that are not in the input dataframe
-        self._confirm_variables(X)
+        if self.variables is None:
+            self.variables_ = find_numerical_variables(X)
+        else:
+            if self.confirm_variables is True:
+                variables_ = retain_variables_if_in_df(X, self.variables)
+                self.variables_ = check_numerical_variables(X, variables_)
+            else:
+                self.variables_ = check_numerical_variables(X, self.variables)
 
-        # find numerical variables or check variables entered by user
-        self.variables_ = _find_or_check_numerical_variables(X, self.variables_)
+        self._cv = list(self.cv) if isinstance(self.cv, GeneratorType) else self.cv
 
         # check that there are more than 1 variable to select from
         self._check_variable_number()
@@ -160,10 +162,11 @@ class BaseRecursiveSelector(BaseSelector):
 
         # train model with all features and cross-validation
         model = cross_validate(
-            self.estimator,
-            X[self.variables_],
-            y,
-            cv=self.cv,
+            estimator=self.estimator,
+            X=X[self.variables_],
+            y=y,
+            cv=self._cv,
+            groups=self.groups,
             scoring=self.scoring,
             return_estimator=True,
         )
@@ -188,6 +191,7 @@ class BaseRecursiveSelector(BaseSelector):
 
         # Aggregate the feature importance returned in each fold
         self.feature_importances_ = feature_importances_cv.mean(axis=1)
+        self.feature_importances_std_ = feature_importances_cv.std(axis=1)
 
         return X, y
 
@@ -205,3 +209,7 @@ class BaseRecursiveSelector(BaseSelector):
         tags_dict["_xfail_checks"]["check_fit2d_1feature"] = msg
 
         return tags_dict
+
+    def __sklearn_tags__(self):
+        tags = super().__sklearn_tags__()
+        return tags
