@@ -2,32 +2,34 @@ from typing import List, Union
 
 import pandas as pd
 
+from feature_engine._check_init_parameters.check_variables import (
+    _check_variables_input_value,
+)
 from feature_engine._docstrings.fit_attributes import (
     _feature_names_in_docstring,
     _n_features_in_docstring,
 )
+from feature_engine._docstrings.init_parameters.selection import (
+    _confirm_variables_docstring,
+)
 from feature_engine._docstrings.methods import _fit_transform_docstring
-from feature_engine._docstrings.substitute import Substitution
-from feature_engine._variable_handling.init_parameter_checks import (
-    _check_init_parameter_variables,
-)
-from feature_engine._variable_handling.variable_type_selection import (
-    _find_all_variables,
-)
-from feature_engine.dataframe_checks import _check_contains_na, check_X
-from feature_engine.selection._docstring import (
+from feature_engine._docstrings.selection._docstring import (
     _get_support_docstring,
     _variables_all_docstring,
     _variables_attribute_docstring,
 )
+from feature_engine._docstrings.substitute import Substitution
+from feature_engine.dataframe_checks import _check_contains_na, check_X
 from feature_engine.selection.base_selector import BaseSelector
 from feature_engine.tags import _return_tags
 
+from .base_selection_functions import _select_all_variables
+
 Variables = Union[None, int, str, List[Union[str, int]]]
 
 
 @Substitution(
-    confirm_variables=BaseSelector._confirm_variables_docstring,
+    confirm_variables=_confirm_variables_docstring,
     variables=_variables_all_docstring,
     variables_=_variables_attribute_docstring,
     feature_names_in_=_feature_names_in_docstring,
@@ -100,6 +102,35 @@ class DropConstantFeatures(BaseSelector):
     See Also
     --------
     sklearn.feature_selection.VarianceThreshold
+
+    Examples
+    --------
+
+    >>> import pandas as pd
+    >>> from feature_engine.selection import DropConstantFeatures
+    >>> X = pd.DataFrame(dict(x1 = [1,1,1,1],
+    >>>                     x2 = ["a", "a", "b", "c"],
+    >>>                     x3 = [True, False, False, True]))
+    >>> dcf = DropConstantFeatures()
+    >>> dcf.fit_transform(X)
+        x2     x3
+    0  a   True
+    1  a  False
+    2  b  False
+    3  c   True
+
+    Additionally, you can set the Threshold for quasi-constant features:
+
+    >>> X = pd.DataFrame(dict(x1 = [1,1,1,1],
+    >>>                      x2 = ["a", "a", "b", "c"],
+    >>>                      x3 = [True, False, False, False]))
+    >>> dcf = DropConstantFeatures(tol = 0.75)
+    >>> dcf.fit_transform(X)
+        x2
+    0  a
+    1  a
+    2  b
+    3  c
     """
 
     def __init__(
@@ -126,7 +157,7 @@ class DropConstantFeatures(BaseSelector):
         super().__init__(confirm_variables)
 
         self.tol = tol
-        self.variables = _check_init_parameter_variables(variables)
+        self.variables = _check_variables_input_value(variables)
         self.missing_values = missing_values
 
     def fit(self, X: pd.DataFrame, y: pd.Series = None):
@@ -144,11 +175,9 @@ class DropConstantFeatures(BaseSelector):
         # check input dataframe
         X = check_X(X)
 
-        # If required exclude variables that are not in the input dataframe
-        self._confirm_variables(X)
-
-        # find all variables or check those entered are present in the dataframe
-        self.variables_ = _find_all_variables(X, self.variables_)
+        self.variables_ = _select_all_variables(
+            X, self.variables, self.confirm_variables
+        )
 
         if self.missing_values == "raise":
             # check if dataset contains na
@@ -199,3 +228,8 @@ class DropConstantFeatures(BaseSelector):
             "check_fit2d_1sample"
         ] = "the transformer raises an error when dropping all columns, ok to fail"
         return tags_dict
+
+    def __sklearn_tags__(self):
+        tags = super().__sklearn_tags__()
+        tags.input_tags.allow_nan = True
+        return tags
