@@ -5,6 +5,7 @@ import pandas as pd
 from feature_engine.dataframe_checks import check_X
 from feature_engine.selection.base_selector import BaseSelector
 from feature_engine.tags import _return_tags
+from feature_engine.variable_handling import check_all_variables
 
 
 class DropFeatures(BaseSelector):
@@ -51,10 +52,25 @@ class DropFeatures(BaseSelector):
 
     transform:
         Drops indicated features.
+
+    Examples
+    --------
+
+    >>> import pandas as pd
+    >>> from feature_engine.selection import DropFeatures
+    >>> X = pd.DataFrame(dict(x1 = [1,2,3,4],
+    >>>                         x2 = ["a", "a", "b", "c"],
+    >>>                         x3 = [True, False, False, True]))
+    >>> df = DropFeatures(features_to_drop=["x2"])
+    >>> df.fit_transform(X)
+        x1     x3
+    0   1   True
+    1   2  False
+    2   3  False
+    3   4   True
     """
 
     def __init__(self, features_to_drop: List[Union[str, int]]):
-
         if not isinstance(features_to_drop, (str, list)) or len(features_to_drop) == 0:
             raise ValueError(
                 f"features_to_drop should be a list with the name of the variables "
@@ -77,14 +93,10 @@ class DropFeatures(BaseSelector):
         # check input dataframe
         X = check_X(X)
 
-        # X[self.features_to_drops] calls to pandas to check if columns are
-        # present in the df.
-        X[self.features_to_drop]
-
-        self.features_to_drop_ = self.features_to_drop
+        self.features_to_drop_ = check_all_variables(X, variables=self.features_to_drop)
 
         # check user is not removing all columns in the dataframe
-        if len(self.features_to_drop) == len(X.columns):
+        if len(self.features_to_drop_) == len(X.columns):
             raise ValueError(
                 "The resulting dataframe will have no columns after dropping all "
                 "existing variables"
@@ -106,3 +118,8 @@ class DropFeatures(BaseSelector):
             "check_fit2d_1feature"
         ] = "the transformer raises an error when removing the only column, ok to fail"
         return tags_dict
+
+    def __sklearn_tags__(self):
+        tags = super().__sklearn_tags__()
+        tags.input_tags.allow_nan = True
+        return tags
