@@ -2,16 +2,24 @@ import pandas as pd
 from sklearn.model_selection import cross_validate
 
 from feature_engine._docstrings.fit_attributes import (
+    _feature_importances_docstring,
+    _feature_importances_std_docstring,
     _feature_names_in_docstring,
     _n_features_in_docstring,
+    _performance_drifts_docstring,
+    _performance_drifts_std_docstring,
+)
+from feature_engine._docstrings.init_parameters.selection import (
+    _confirm_variables_docstring,
+    _estimator_docstring,
 )
 from feature_engine._docstrings.methods import _fit_transform_docstring
-from feature_engine._docstrings.substitute import Substitution
-from feature_engine.selection._docstring import (
+from feature_engine._docstrings.selection._docstring import (
     _cv_docstring,
     _features_to_drop_docstring,
     _fit_docstring,
     _get_support_docstring,
+    _groups_docstring,
     _initial_model_performance_docstring,
     _scoring_docstring,
     _threshold_docstring,
@@ -19,19 +27,23 @@ from feature_engine.selection._docstring import (
     _variables_attribute_docstring,
     _variables_numerical_docstring,
 )
+from feature_engine._docstrings.substitute import Substitution
 from feature_engine.selection.base_recursive_selector import BaseRecursiveSelector
 
 
 @Substitution(
-    estimator=BaseRecursiveSelector._estimator_docstring,
+    estimator=_estimator_docstring,
     scoring=_scoring_docstring,
     threshold=_threshold_docstring,
     cv=_cv_docstring,
+    groups=_groups_docstring,
     variables=_variables_numerical_docstring,
-    confirm_variables=BaseRecursiveSelector._confirm_variables_docstring,
+    confirm_variables=_confirm_variables_docstring,
     initial_model_performance_=_initial_model_performance_docstring,
-    feature_importances_=BaseRecursiveSelector._feature_importances_docstring,
-    performance_drifts_=BaseRecursiveSelector._performance_drifts_docstring,
+    feature_importances_=_feature_importances_docstring,
+    feature_importances_std_=_feature_importances_std_docstring,
+    performance_drifts_=_performance_drifts_docstring,
+    performance_drifts_std_=_performance_drifts_std_docstring,
     features_to_drop_=_features_to_drop_docstring,
     variables_=_variables_attribute_docstring,
     feature_names_in_=_feature_names_in_docstring,
@@ -78,6 +90,8 @@ class RecursiveFeatureElimination(BaseRecursiveSelector):
 
     {cv}
 
+    {groups}
+
     {confirm_variables}
 
     Attributes
@@ -86,8 +100,12 @@ class RecursiveFeatureElimination(BaseRecursiveSelector):
 
     {feature_importances_}
 
+    {feature_importances_std_}
+
     {performance_drifts_}
 
+    {performance_drifts_std_}
+
     {features_to_drop_}
 
     {variables_}
@@ -106,6 +124,27 @@ class RecursiveFeatureElimination(BaseRecursiveSelector):
 
     {transform}
 
+    Examples
+    --------
+
+    >>> import pandas as pd
+    >>> from sklearn.ensemble import RandomForestClassifier
+    >>> from feature_engine.selection import RecursiveFeatureElimination
+    >>> X = pd.DataFrame(dict(x1 = [1000,2000,1000,1000,2000,3000],
+    >>>                     x2 = [2,4,3,1,2,2],
+    >>>                     x3 = [1,1,1,0,0,0],
+    >>>                     x4 = [1,2,1,1,0,1],
+    >>>                     x5 = [1,1,1,1,1,1]))
+    >>> y = pd.Series([1,0,0,1,1,0])
+    >>> rfe = RecursiveFeatureElimination(RandomForestClassifier(random_state=2), cv=2)
+    >>> rfe.fit_transform(X, y)
+       x2
+    0   2
+    1   4
+    2   3
+    3   1
+    4   2
+    5   2
     """
 
     def fit(self, X: pd.DataFrame, y: pd.Series):
@@ -137,17 +176,25 @@ class RecursiveFeatureElimination(BaseRecursiveSelector):
 
         # dict to collect features and their performance_drift after shuffling
         self.performance_drifts_ = {}
+        self.performance_drifts_std_ = {}
 
         # evaluate every feature, starting from the least important
         # remember that feature_importances_ is ordered already
         for feature in list(self.feature_importances_.index):
 
+            # if there is only 1 feature left
+            if X_tmp.shape[1] == 1:
+                self.performance_drifts_[feature] = 0
+                _selected_features.append(feature)
+                break
+
             # remove feature and train new model
             model_tmp = cross_validate(
-                self.estimator,
-                X_tmp.drop(columns=feature),
-                y,
-                cv=self.cv,
+                estimator=self.estimator,
+                X=X_tmp.drop(columns=feature),
+                y=y,
+                cv=self._cv,
+                groups=self.groups,
                 scoring=self.scoring,
                 return_estimator=False,
             )
@@ -160,6 +207,7 @@ class RecursiveFeatureElimination(BaseRecursiveSelector):
 
             # Save feature and performance drift
             self.performance_drifts_[feature] = performance_drift
+            self.performance_drifts_std_[feature] = model_tmp["test_score"].std()
 
             if performance_drift > self.threshold:
 
@@ -169,16 +217,12 @@ class RecursiveFeatureElimination(BaseRecursiveSelector):
                 # remove feature and adjust initial performance
                 X_tmp = X_tmp.drop(columns=feature)
 
-                if X_tmp.empty is True:
-                    raise ValueError(
-                        "All features have been removed. Try reducing the threshold."
-                    )
-
                 baseline_model = cross_validate(
-                    self.estimator,
-                    X_tmp,
-                    y,
-                    cv=self.cv,
+                    estimator=self.estimator,
+                    X=X_tmp,
+                    y=y,
+                    cv=self._cv,
+                    groups=self.groups,
                     return_estimator=False,
                     scoring=self.scoring,
                 )
