@@ -1,26 +1,25 @@
-from typing import List, Union
+from types import GeneratorType
+from typing import List, MutableSequence, Union
 
 import numpy as np
 import pandas as pd
 from sklearn.base import is_classifier
 from sklearn.metrics import get_scorer
 from sklearn.model_selection import check_cv, cross_validate
-from sklearn.utils.validation import check_random_state
+from sklearn.utils.validation import _check_sample_weight, check_random_state
 
+from feature_engine._check_init_parameters.check_variables import (
+    _check_variables_input_value,
+)
 from feature_engine._docstrings.fit_attributes import (
     _feature_names_in_docstring,
     _n_features_in_docstring,
 )
+from feature_engine._docstrings.init_parameters.selection import (
+    _confirm_variables_docstring,
+)
 from feature_engine._docstrings.methods import _fit_transform_docstring
-from feature_engine._docstrings.substitute import Substitution
-from feature_engine._variable_handling.init_parameter_checks import (
-    _check_init_parameter_variables,
-)
-from feature_engine._variable_handling.variable_type_selection import (
-    _find_or_check_numerical_variables,
-)
-from feature_engine.dataframe_checks import check_X_y
-from feature_engine.selection._docstring import (
+from feature_engine._docstrings.selection._docstring import (
     _cv_docstring,
     _estimator_docstring,
     _features_to_drop_docstring,
@@ -33,9 +32,13 @@ from feature_engine.selection._docstring import (
     _variables_attribute_docstring,
     _variables_numerical_docstring,
 )
+from feature_engine._docstrings.substitute import Substitution
+from feature_engine.dataframe_checks import check_X_y
 from feature_engine.selection.base_selector import BaseSelector
 from feature_engine.tags import _return_tags
 
+from .base_selection_functions import _select_numerical_variables
+
 Variables = Union[None, int, str, List[Union[str, int]]]
 
 
@@ -45,7 +48,7 @@ Variables = Union[None, int, str, List[Union[str, int]]]
     threshold=_threshold_docstring,
     cv=_cv_docstring,
     variables=_variables_numerical_docstring,
-    confirm_variables=BaseSelector._confirm_variables_docstring,
+    confirm_variables=_confirm_variables_docstring,
     initial_model_performance_=_initial_model_performance_docstring,
     features_to_drop_=_features_to_drop_docstring,
     variables_=_variables_attribute_docstring,
@@ -104,6 +107,10 @@ class SelectByShuffling(BaseSelector):
     performance_drifts_:
         Dictionary with the performance drift per shuffled feature.
 
+    performance_drifts_std_:
+        Dictionary with the standard deviation of performance drift per shuffled
+        feature.
+
     {features_to_drop_}
 
     {variables_}
@@ -131,6 +138,32 @@ class SelectByShuffling(BaseSelector):
     See Also
     --------
     sklearn.inspection.permutation_importance
+
+    Examples
+    --------
+
+    >>> import pandas as pd
+    >>> from sklearn.ensemble import RandomForestClassifier
+    >>> from feature_engine.selection import SelectByShuffling
+    >>> X = pd.DataFrame(dict(x1 = [1000,2000,1000,1000,2000,3000],
+    >>>                     x2 = [2,4,3,1,2,2],
+    >>>                     x3 = [1,1,1,0,0,0],
+    >>>                     x4 = [1,2,1,1,0,1],
+    >>>                     x5 = [1,1,1,1,1,1]))
+    >>> y = pd.Series([1,0,0,1,1,0])
+    >>> sbs = SelectByShuffling(
+    >>>         RandomForestClassifier(random_state=42),
+    >>>         cv=2,
+    >>>         random_state=42,
+    >>>       )
+    >>> sbs.fit_transform(X, y)
+       x2  x4  x5
+    0   2   1   1
+    1   4   2   1
+    2   3   1   1
+    3   1   1   1
+    4   2   0   1
+    5   2   1   1
     """
 
     def __init__(
@@ -138,9 +171,9 @@ class SelectByShuffling(BaseSelector):
         estimator,
         scoring: str = "roc_auc",
         cv=3,
-        threshold: Union[float, int] = None,
+        threshold: Union[float, int, None] = None,
         variables: Variables = None,
-        random_state: int = None,
+        random_state: Union[int, None] = None,
         confirm_variables: bool = False,
     ):
 
@@ -149,14 +182,19 @@ class SelectByShuffling(BaseSelector):
 
         super().__init__(confirm_variables)
 
-        self.variables = _check_init_parameter_variables(variables)
+        self.variables = _check_variables_input_value(variables)
         self.estimator = estimator
         self.scoring = scoring
         self.threshold = threshold
         self.cv = cv
         self.random_state = random_state
 
-    def fit(self, X: pd.DataFrame, y: pd.Series):
+    def fit(
+        self,
+        X: pd.DataFrame,
+        y: pd.Series,
+        sample_weight: Union[MutableSequence, None] = None,
+    ):
         """
         Find the important features.
 
@@ -164,8 +202,12 @@ class SelectByShuffling(BaseSelector):
         ----------
         X: pandas dataframe of shape = [n_samples, n_features]
            The input dataframe.
+
         y: array-like of shape (n_samples)
            Target variable. Required to train the estimator.
+
+        sample_weight : array-like of shape (n_samples,), default=None
+            Sample weights. If None, then samples are equally weighted.
         """
 
         X, y = check_X_y(X, y)
@@ -174,30 +216,34 @@ class SelectByShuffling(BaseSelector):
         X = X.reset_index(drop=True)
         y = y.reset_index(drop=True)
 
-        # If required exclude variables that are not in the input dataframe
-        self._confirm_variables(X)
+        if sample_weight is not None:
+            sample_weight = _check_sample_weight(sample_weight, X)
 
-        # find numerical variables or check variables entered by user
-        self.variables_ = _find_or_check_numerical_variables(X, self.variables_)
+        self.variables_ = _select_numerical_variables(
+            X, self.variables, self.confirm_variables
+        )
 
         # check that there are more than 1 variable to select from
         self._check_variable_number()
 
+        cv = list(self.cv) if isinstance(self.cv, GeneratorType) else self.cv
+
         # train model with all features and cross-validation
         model = cross_validate(
-            self.estimator,
-            X[self.variables_],
-            y,
-            cv=self.cv,
+            estimator=self.estimator,
+            X=X[self.variables_],
+            y=y,
+            cv=cv,
             return_estimator=True,
             scoring=self.scoring,
+            params={"sample_weight": sample_weight},
         )
 
         # store initial model performance
         self.initial_model_performance_ = model["test_score"].mean()
 
         # extract the validation folds
-        cv_ = check_cv(self.cv, y=y, classifier=is_classifier(self.estimator))
+        cv_ = check_cv(cv, y=y, classifier=is_classifier(self.estimator))
         validation_indices = [val_index for _, val_index in cv_.split(X, y)]
 
         # get performance metric
@@ -208,6 +254,7 @@ class SelectByShuffling(BaseSelector):
 
         # dict to collect features and their performance_drift after shuffling
         self.performance_drifts_ = {}
+        self.performance_drifts_std_ = {}
 
         # shuffle features and save feature performance drift into a dict
         for feature in self.variables_:
@@ -222,12 +269,13 @@ class SelectByShuffling(BaseSelector):
             )
 
             # determine the performance with the shuffled feature
-            performance = np.mean(
-                [
-                    scorer(m, X_shuffled.iloc[idx], y.iloc[idx])
-                    for m, idx in zip(model["estimator"], validation_indices)
-                ]
-            )
+            performance = [
+                scorer(m, X_shuffled.iloc[idx], y.iloc[idx])
+                for m, idx in zip(model["estimator"], validation_indices)
+            ]
+
+            performance_std = np.std(performance)
+            performance = np.mean(performance)
 
             # determine drift in performance
             # Note, sklearn negates the log and error scores, so no need to manually
@@ -239,6 +287,7 @@ class SelectByShuffling(BaseSelector):
 
             # Save feature and performance drift
             self.performance_drifts_[feature] = performance_drift
+            self.performance_drifts_std_[feature] = performance_std
 
         # select features
         if not self.threshold:
@@ -271,3 +320,7 @@ class SelectByShuffling(BaseSelector):
         tags_dict["_xfail_checks"]["check_fit2d_1feature"] = msg
 
         return tags_dict
+
+    def __sklearn_tags__(self):
+        tags = super().__sklearn_tags__()
+        return tags
