@@ -1,34 +1,36 @@
+from types import GeneratorType
 from typing import List, Union
 
 import pandas as pd
 from sklearn.base import clone
 from sklearn.model_selection import cross_validate
 
+from feature_engine._check_init_parameters.check_variables import (
+    _check_variables_input_value,
+)
 from feature_engine._docstrings.fit_attributes import (
     _feature_names_in_docstring,
     _n_features_in_docstring,
 )
+from feature_engine._docstrings.init_parameters.selection import (
+    _confirm_variables_docstring,
+)
 from feature_engine._docstrings.methods import _fit_transform_docstring
-from feature_engine._docstrings.substitute import Substitution
-from feature_engine._prediction.target_mean_classifier import TargetMeanClassifier
-from feature_engine._prediction.target_mean_regressor import TargetMeanRegressor
-from feature_engine._variable_handling.init_parameter_checks import (
-    _check_init_parameter_variables,
-)
-from feature_engine._variable_handling.variable_type_selection import (
-    _find_all_variables,
-)
-from feature_engine.dataframe_checks import check_X_y
-from feature_engine.selection._docstring import (
+from feature_engine._docstrings.selection._docstring import (
     _cv_docstring,
     _features_to_drop_docstring,
     _fit_docstring,
     _get_support_docstring,
+    _groups_docstring,
     _scoring_docstring,
     _threshold_docstring,
     _transform_docstring,
     _variables_attribute_docstring,
 )
+from feature_engine._docstrings.substitute import Substitution
+from feature_engine._prediction.target_mean_classifier import TargetMeanClassifier
+from feature_engine._prediction.target_mean_regressor import TargetMeanRegressor
+from feature_engine.dataframe_checks import check_X_y
 from feature_engine.selection._selection_constants import (
     _CLASSIFICATION_METRICS,
     _REGRESSION_METRICS,
@@ -36,6 +38,8 @@ from feature_engine.selection._selection_constants import (
 from feature_engine.selection.base_selector import BaseSelector
 from feature_engine.tags import _return_tags
 
+from .base_selection_functions import _select_all_variables
+
 Variables = Union[None, int, str, List[Union[str, int]]]
 
 
@@ -43,7 +47,8 @@ Variables = Union[None, int, str, List[Union[str, int]]]
     scoring=_scoring_docstring,
     threshold=_threshold_docstring,
     cv=_cv_docstring,
-    confirm_variables=BaseSelector._confirm_variables_docstring,
+    groups=_groups_docstring,
+    confirm_variables=_confirm_variables_docstring,
     features_to_drop_=_features_to_drop_docstring,
     variables_=_variables_attribute_docstring,
     feature_names_in_=_feature_names_in_docstring,
@@ -122,7 +127,9 @@ class SelectByTargetMeanPerformance(BaseSelector):
 
     {cv}
 
-    regression: boolean, default=True
+    {groups}
+
+    regression: boolean, default=False
         Indicates whether the target is one for regression or a classification.
 
     {confirm_variables}
@@ -134,6 +141,9 @@ class SelectByTargetMeanPerformance(BaseSelector):
     feature_performance_:
         Dictionary with the performance of each feature.
 
+    feature_performance_std_:
+        Dictionary with the standard deviation of each feature's performance.
+
     {features_to_drop_}
 
     {feature_names_in_}
@@ -166,6 +176,41 @@ class SelectByTargetMeanPerformance(BaseSelector):
     .. [1] Miller, et al. "Predicting customer behaviour: The University of Melbourne’s
         KDD Cup report". JMLR Workshop and Conference Proceeding. KDD 2009
         http://proceedings.mlr.press/v7/miller09/miller09.pdf
+
+    Examples
+    --------
+
+    >>> from sklearn.ensemble import RandomForestClassifier
+    >>> from feature_engine.selection import SelectByTargetMeanPerformance
+    >>> X = pd.DataFrame(dict(x1 = [1000,2000,1000,1000,2000,3000],
+    >>>                     x2 = [1,1,1,0,0,0],
+    >>>                     x3 = [1,2,1,1,0,1],
+    >>>                     x4 = [1,1,1,1,1,1]))
+    >>> y = pd.Series([1,0,0,1,1,0])
+    >>> tmp = SelectByTargetMeanPerformance(bins = 3, cv=2,scoring='accuracy')
+    >>> tmp.fit_transform(X, y)
+        x2  x3  x4
+    0   1   1   1
+    1   1   2   1
+    2   1   1   1
+    3   0   1   1
+    4   0   0   1
+    5   0   1   1
+
+    This transformer also works with Categorical examples:
+
+    >>> X = pd.DataFrame(dict(x1 = ["a","b","a","a","b","b"],
+    >>>             x2 = ["a","a","a","b","b","b"]))
+    >>> y = pd.Series([1,0,0,1,1,0])
+    >>> tmp = SelectByTargetMeanPerformance(bins = 3, cv=2,scoring='accuracy')
+    >>> tmp.fit_transform(X, y)
+      x2
+    0  a
+    1  a
+    2  a
+    3  b
+    4  b
+    5  b
     """
 
     def __init__(
@@ -175,7 +220,8 @@ class SelectByTargetMeanPerformance(BaseSelector):
         strategy: str = "equal_width",
         scoring: str = "roc_auc",
         cv=3,
-        threshold: Union[int, float] = None,
+        groups=None,
+        threshold: Union[int, float, None] = None,
         regression: bool = False,
         confirm_variables: bool = False,
     ):
@@ -209,11 +255,12 @@ class SelectByTargetMeanPerformance(BaseSelector):
             )
 
         super().__init__(confirm_variables)
-        self.variables = _check_init_parameter_variables(variables)
+        self.variables = _check_variables_input_value(variables)
         self.bins = bins
         self.strategy = strategy
         self.scoring = scoring
         self.cv = cv
+        self.groups = groups
         self.threshold = threshold
         self.regression = regression
 
@@ -232,11 +279,9 @@ class SelectByTargetMeanPerformance(BaseSelector):
         # check input dataframe
         X, y = check_X_y(X, y)
 
-        # If required exclude variables that are not in the input dataframe
-        self._confirm_variables(X)
-
-        # find all variables or check those entered are present in the dataframe
-        self.variables_ = _find_all_variables(X, self.variables_, exclude_datetime=True)
+        self.variables_ = _select_all_variables(
+            X, self.variables, self.confirm_variables, exclude_datetime=True
+        )
 
         if len(self.variables_) == 1 and self.threshold is None:
             raise ValueError(
@@ -263,6 +308,9 @@ class SelectByTargetMeanPerformance(BaseSelector):
             )
 
         self.feature_performance_ = {}
+        self.feature_performance_std_ = {}
+
+        cv = list(self.cv) if isinstance(self.cv, GeneratorType) else self.cv
 
         for variable in self.variables_:
             # clone estimator
@@ -272,14 +320,16 @@ class SelectByTargetMeanPerformance(BaseSelector):
             estimator.set_params(variables=variable)
 
             model = cross_validate(
-                estimator,
-                X,
-                y,
-                cv=self.cv,
+                estimator=estimator,
+                X=X,
+                y=y,
+                cv=cv,
+                groups=self.groups,
                 scoring=self.scoring,
             )
 
             self.feature_performance_[variable] = model["test_score"].mean()
+            self.feature_performance_std_[variable] = model["test_score"].std()
 
         # select features
         if not self.threshold:
@@ -302,3 +352,7 @@ class SelectByTargetMeanPerformance(BaseSelector):
         msg = "transformers need more than 1 feature to work"
         tags_dict["_xfail_checks"]["check_fit2d_1feature"] = msg
         return tags_dict
+
+    def __sklearn_tags__(self):
+        tags = super().__sklearn_tags__()
+        return tags
