@@ -4,23 +4,23 @@ import pandas as pd
 from sklearn.base import BaseEstimator, TransformerMixin
 from sklearn.utils.validation import check_is_fitted
 
-from feature_engine._base_transformers.mixins import GetFeatureNamesOutMixin
+from feature_engine._base_transformers.mixins import (
+    GetFeatureNamesOutMixin,
+    TransformXyMixin,
+)
+from feature_engine._check_init_parameters.check_variables import (
+    _check_variables_input_value,
+)
 from feature_engine._docstrings.fit_attributes import (
     _feature_names_in_docstring,
     _n_features_in_docstring,
 )
-from feature_engine._docstrings.init_parameters import (
+from feature_engine._docstrings.init_parameters.all_trasnformers import (
     _drop_original_docstring,
     _missing_values_docstring,
 )
 from feature_engine._docstrings.methods import _fit_not_learn_docstring
 from feature_engine._docstrings.substitute import Substitution
-from feature_engine._variable_handling.init_parameter_checks import (
-    _check_init_parameter_variables,
-)
-from feature_engine._variable_handling.variable_type_selection import (
-    _find_or_check_numerical_variables,
-)
 from feature_engine.dataframe_checks import (
     _check_contains_inf,
     _check_contains_na,
@@ -28,6 +28,10 @@ from feature_engine.dataframe_checks import (
     check_X,
 )
 from feature_engine.tags import _return_tags
+from feature_engine.variable_handling import (
+    check_numerical_variables,
+    find_numerical_variables,
+)
 
 
 @Substitution(
@@ -37,7 +41,9 @@ from feature_engine.tags import _return_tags
     fit=_fit_not_learn_docstring,
     n_features_in_=_n_features_in_docstring,
 )
-class BaseForecastTransformer(BaseEstimator, TransformerMixin, GetFeatureNamesOutMixin):
+class BaseForecastTransformer(
+    TransformerMixin, BaseEstimator, GetFeatureNamesOutMixin, TransformXyMixin
+):
     """
     Shared methods across time-series forecasting transformers.
 
@@ -50,6 +56,9 @@ class BaseForecastTransformer(BaseEstimator, TransformerMixin, GetFeatureNamesOu
 
     {drop_original}
 
+    drop_na: bool, default=False.
+        Whether the NAN introduced in the created features should be removed.
+
     Attributes
     ----------
     {feature_names_in_}
@@ -63,6 +72,7 @@ class BaseForecastTransformer(BaseEstimator, TransformerMixin, GetFeatureNamesOu
         variables: Union[None, int, str, List[Union[str, int]]] = None,
         missing_values: str = "raise",
         drop_original: bool = False,
+        drop_na: bool = False,
     ) -> None:
 
         if missing_values not in ["raise", "ignore"]:
@@ -77,9 +87,16 @@ class BaseForecastTransformer(BaseEstimator, TransformerMixin, GetFeatureNamesOu
                 f"Got {drop_original} instead."
             )
 
-        self.variables = _check_init_parameter_variables(variables)
+        if not isinstance(drop_na, bool):
+            raise ValueError(
+                "drop_na takes only boolean values True and False. "
+                f"Got {drop_na} instead."
+            )
+
+        self.variables = _check_variables_input_value(variables)
         self.missing_values = missing_values
         self.drop_original = drop_original
+        self.drop_na = drop_na
 
     def _check_index(self, X: pd.DataFrame):
         """
@@ -155,7 +172,10 @@ class BaseForecastTransformer(BaseEstimator, TransformerMixin, GetFeatureNamesOu
         self._check_index(X)
 
         # find or check for numerical variables
-        self.variables_ = _find_or_check_numerical_variables(X, self.variables)
+        if self.variables is None:
+            self.variables_ = find_numerical_variables(X)
+        else:
+            self.variables_ = check_numerical_variables(X, self.variables)
 
         # check if dataset contains na
         if self.missing_values == "raise":
@@ -165,7 +185,7 @@ class BaseForecastTransformer(BaseEstimator, TransformerMixin, GetFeatureNamesOu
 
         return self
 
-    def transform(self, X: pd.DataFrame) -> pd.DataFrame:
+    def _check_transform_input_and_state(self, X: pd.DataFrame) -> pd.DataFrame:
         """
         Common checks performed before the feature transformation.
 
@@ -214,3 +234,7 @@ class BaseForecastTransformer(BaseEstimator, TransformerMixin, GetFeatureNamesOu
             "check_methods_subset_invariance"
         ] = "LagFeatures is not invariant when applied to a subset. Not sure why yet"
         return tags_dict
+
+    def __sklearn_tags__(self):
+        tags = super().__sklearn_tags__()
+        return tags
