@@ -2,6 +2,7 @@
 # License: BSD 3 clause
 
 from __future__ import annotations
+
 from typing import List
 
 import pandas as pd
@@ -10,7 +11,7 @@ from feature_engine._docstrings.fit_attributes import (
     _feature_names_in_docstring,
     _n_features_in_docstring,
 )
-from feature_engine._docstrings.init_parameters import (
+from feature_engine._docstrings.init_parameters.all_trasnformers import (
     _drop_original_docstring,
     _missing_values_docstring,
     _variables_numerical_docstring,
@@ -92,6 +93,10 @@ class ExpandingWindowFeatures(BaseForecastTransformer):
 
     {drop_original}
 
+    drop_na: bool, default=False.
+        Whether the NAN introduced in the created features should be removed.
+
+
     Attributes
     ----------
     variables_:
@@ -109,6 +114,9 @@ class ExpandingWindowFeatures(BaseForecastTransformer):
     transform:
         Add expanding window features.
 
+    transform_x_y:
+        Remove rows with missing data from X and y.
+
     {fit_transform}
 
     See Also
@@ -116,6 +124,28 @@ class ExpandingWindowFeatures(BaseForecastTransformer):
     pandas.expanding
     pandas.aggregate
     pandas.shift
+
+    Examples
+    --------
+
+    >>> import pandas as pd
+    >>> from feature_engine.timeseries.forecasting import ExpandingWindowFeatures
+    >>> X = pd.DataFrame(dict(date = ["2022-09-18",
+    >>>                               "2022-09-19",
+    >>>                               "2022-09-20",
+    >>>                               "2022-09-21",
+    >>>                               "2022-09-22"],
+    >>>                       x1 = [1,2,3,4,5],
+    >>>                       x2 = [6,7,8,9,10]
+    >>>                     ))
+    >>> ewf = ExpandingWindowFeatures()
+    >>> ewf.fit_transform(X)
+             date  x1  x2  x1_expanding_mean  x2_expanding_mean
+    0  2022-09-18   1   6                NaN                NaN
+    1  2022-09-19   2   7                1.0                6.0
+    2  2022-09-20   3   8                1.5                6.5
+    3  2022-09-21   4   9                2.0                7.0
+    4  2022-09-22   5  10                2.5                7.5
     """
 
     def __init__(
@@ -124,10 +154,11 @@ class ExpandingWindowFeatures(BaseForecastTransformer):
         min_periods: int | None = None,
         functions: str | list[str] = "mean",
         periods: int = 1,
-        freq: str = None,
+        freq: str | None = None,
         sort_index: bool = True,
         missing_values: str = "raise",
         drop_original: bool = False,
+        drop_na: bool = False,
     ) -> None:
 
         if not isinstance(functions, (str, list)) or not all(
@@ -145,7 +176,7 @@ class ExpandingWindowFeatures(BaseForecastTransformer):
                 f"periods must be a non-negative integer. Got {periods} instead."
             )
 
-        super().__init__(variables, missing_values, drop_original)
+        super().__init__(variables, missing_values, drop_original, drop_na)
 
         self.min_periods = min_periods
         self.functions = functions
@@ -168,7 +199,7 @@ class ExpandingWindowFeatures(BaseForecastTransformer):
             The dataframe with the original plus the new variables.
         """
         # Common dataframe checks and setting up.
-        X = super().transform(X)
+        X = self._check_transform_input_and_state(X)
 
         tmp = (
             X[self.variables_]
@@ -184,6 +215,9 @@ class ExpandingWindowFeatures(BaseForecastTransformer):
         if self.drop_original:
             X = X.drop(self.variables_, axis=1)
 
+        if self.drop_na:
+            X = X.dropna(subset=tmp.columns, axis=0)
+
         return X
 
     def _get_new_features_name(self) -> List:
