@@ -7,21 +7,23 @@ import numpy as np
 import pandas as pd
 
 from feature_engine._base_transformers.base_numerical import BaseNumericalTransformer
+from feature_engine._check_init_parameters.check_variables import (
+    _check_variables_input_value,
+)
 from feature_engine._docstrings.fit_attributes import (
     _feature_names_in_docstring,
     _n_features_in_docstring,
     _variables_attribute_docstring,
 )
-from feature_engine._docstrings.init_parameters import _variables_numerical_docstring
+from feature_engine._docstrings.init_parameters.all_trasnformers import (
+    _variables_numerical_docstring,
+)
 from feature_engine._docstrings.methods import (
     _fit_not_learn_docstring,
     _fit_transform_docstring,
     _inverse_transform_docstring,
 )
 from feature_engine._docstrings.substitute import Substitution
-from feature_engine._variable_handling.init_parameter_checks import (
-    _check_init_parameter_variables,
-)
 from feature_engine.tags import _return_tags
 
 
@@ -78,13 +80,31 @@ class ArcsinTransformer(BaseNumericalTransformer):
     transform:
         Apply the arcsin transformation.
 
+    Examples
+    --------
+
+    >>> import numpy as np
+    >>> import pandas as pd
+    >>> from feature_engine.transformation import ArcsinTransformer
+    >>> np.random.seed(42)
+    >>> X = pd.DataFrame(dict(x = np.random.beta(1, 1, size = 100)))
+    >>> ast = ArcsinTransformer()
+    >>> ast.fit(X)
+    >>> X = ast.transform(X)
+    >>> X.head()
+              x
+    0  0.785437
+    1  0.253389
+    2  0.144664
+    3  0.783236
+    4  0.650777
     """
 
     def __init__(
         self, variables: Union[None, int, str, List[Union[str, int]]] = None
     ) -> None:
 
-        self.variables = _check_init_parameter_variables(variables)
+        self.variables = _check_variables_input_value(variables)
 
     def fit(self, X: pd.DataFrame, y: Optional[pd.Series] = None):
         """
@@ -128,7 +148,7 @@ class ArcsinTransformer(BaseNumericalTransformer):
         """
 
         # check input dataframe and if class was fitted
-        X = super().transform(X)
+        X = self._check_transform_input_and_state(X)
 
         # check if the variables are in the correct range
         if ((X[self.variables_] < 0) | (X[self.variables_] > 1)).any().any():
@@ -186,3 +206,6 @@ class ArcsinTransformer(BaseNumericalTransformer):
         tags_dict["_xfail_checks"]["check_n_features_in"] = msg
 
         return tags_dict
+
+    def __sklearn_tags__(self):
+        return super().__sklearn_tags__()
