@@ -7,21 +7,23 @@ import numpy as np
 import pandas as pd
 
 from feature_engine._base_transformers.base_numerical import BaseNumericalTransformer
+from feature_engine._check_init_parameters.check_variables import (
+    _check_variables_input_value,
+)
 from feature_engine._docstrings.fit_attributes import (
     _feature_names_in_docstring,
     _n_features_in_docstring,
     _variables_attribute_docstring,
 )
-from feature_engine._docstrings.init_parameters import _variables_numerical_docstring
+from feature_engine._docstrings.init_parameters.all_trasnformers import (
+    _variables_numerical_docstring,
+)
 from feature_engine._docstrings.methods import (
     _fit_not_learn_docstring,
     _fit_transform_docstring,
     _inverse_transform_docstring,
 )
 from feature_engine._docstrings.substitute import Substitution
-from feature_engine._variable_handling.init_parameter_checks import (
-    _check_init_parameter_variables,
-)
 
 
 @Substitution(
@@ -72,6 +74,24 @@ class PowerTransformer(BaseNumericalTransformer):
     transform:
         Apply the power transformation to the variables.
 
+    Examples
+    --------
+
+    >>> import numpy as np
+    >>> import pandas as pd
+    >>> from feature_engine.transformation import PowerTransformer
+    >>> np.random.seed(42)
+    >>> X = pd.DataFrame(dict(x = np.random.lognormal(size = 100)))
+    >>> pt = PowerTransformer()
+    >>> pt.fit(X)
+    >>> X = pt.transform(X)
+    >>> X.head()
+              x
+    0  1.281918
+    1  0.933203
+    2  1.382432
+    3  2.141518
+    4  0.889517
     """
 
     def __init__(
@@ -84,7 +104,7 @@ class PowerTransformer(BaseNumericalTransformer):
             raise ValueError("exp must be a float or an int")
 
         self.exp = exp
-        self.variables = _check_init_parameter_variables(variables)
+        self.variables = _check_variables_input_value(variables)
 
     def fit(self, X: pd.DataFrame, y: Optional[pd.Series] = None):
         """
@@ -121,9 +141,10 @@ class PowerTransformer(BaseNumericalTransformer):
         """
 
         # check input dataframe and if class was fitted
-        X = super().transform(X)
+        X = self._check_transform_input_and_state(X)
 
         # transform
+        X[self.variables_] = X[self.variables_].astype(float)
         X.loc[:, self.variables_] = np.power(X.loc[:, self.variables_], self.exp)
 
         return X
@@ -144,7 +165,7 @@ class PowerTransformer(BaseNumericalTransformer):
         """
 
         # check input dataframe and if class was fitted
-        X = super().transform(X)
+        X = self._check_transform_input_and_state(X)
 
         # inverse_transform
         X.loc[:, self.variables_] = np.power(X.loc[:, self.variables_], 1 / self.exp)
