@@ -53,6 +53,17 @@ def test_error_if_func_not_supported(_func):
         )
 
 
+@pytest.mark.parametrize("_fill_value", [(2, 3.3), ["test"], "python"])
+def test_error_if_fill_value_not_permitted(_fill_value):
+    with pytest.raises(ValueError):
+        RelativeFeatures(
+            variables=["Age"],
+            reference=["Marks"],
+            func=["sub", "div", "add", "mul"],
+            fill_value=_fill_value,
+        )
+
+
 def test_error_when_drop_original_not_bool():
     for drop_original in ["True", [True]]:
         with pytest.raises(ValueError):
@@ -116,7 +127,7 @@ def test_classic_binary_operation(df_vartypes):
             "City": ["London", "Manchester", "Liverpool", "Bristol"],
             "Age": [20, 21, 19, 18],
             "Marks": [0.9, 0.8, 0.7, 0.6],
-            "dob": pd.date_range("2020-02-24", periods=4, freq="T"),
+            "dob": pd.date_range("2020-02-24", periods=4, freq="min"),
             "Age_sub_Marks": [19.1, 20.2, 18.3, 17.4],
             "Age_div_Marks": [22.22222222222222, 26.25, 27.142857142857146, 30.0],
             "Age_add_Marks": [20.9, 21.8, 19.7, 18.6],
@@ -164,7 +175,7 @@ def test_operations_with_multiple_variables(df_vartypes):
             "City": ["London", "Manchester", "Liverpool", "Bristol"],
             "Age": [20, 21, 19, 18],
             "Marks": [0.9, 0.8, 0.7, 0.6],
-            "dob": pd.date_range("2020-02-24", periods=4, freq="T"),
+            "dob": pd.date_range("2020-02-24", periods=4, freq="min"),
             "Age_sub_Age": [0, 0, 0, 0],
             "Marks_sub_Age": [-19.1, -20.2, -18.3, -17.4],
             "Age_sub_Marks": [19.1, 20.2, 18.3, 17.4],
@@ -190,7 +201,7 @@ def test_multiple_operations_with_multiple_variables(df_vartypes):
             "City": ["London", "Manchester", "Liverpool", "Bristol"],
             "Age": [20, 21, 19, 18],
             "Marks": [0.9, 0.8, 0.7, 0.6],
-            "dob": pd.date_range("2020-02-24", periods=4, freq="T"),
+            "dob": pd.date_range("2020-02-24", periods=4, freq="min"),
             "Age_sub_Age": [0, 0, 0, 0],
             "Marks_sub_Age": [-19.1, -20.2, -18.3, -17.4],
             "Age_sub_Marks": [19.1, 20.2, 18.3, 17.4],
@@ -218,7 +229,7 @@ def test_multiple_operations_with_multiple_variables(df_vartypes):
             "City": ["London", "Manchester", "Liverpool", "Bristol"],
             "Age": [20, 21, 19, 18],
             "Marks": [0.9, 0.8, 0.7, 0.6],
-            "dob": pd.date_range("2020-02-24", periods=4, freq="T"),
+            "dob": pd.date_range("2020-02-24", periods=4, freq="min"),
             "Age_add_Age": [40, 42, 38, 36],
             "Marks_add_Age": [20.9, 21.8, 19.7, 18.6],
             "Age_add_Marks": [20.9, 21.8, 19.7, 18.6],
@@ -253,7 +264,7 @@ def test_when_missing_values_is_ignore(df_vartypes):
             "City": ["London", "Manchester", "Liverpool", "Bristol"],
             "Age": [20, np.nan, 19, 18],
             "Marks": [0.9, 0.8, 0.7, 0.6],
-            "dob": pd.date_range("2020-02-24", periods=4, freq="T"),
+            "dob": pd.date_range("2020-02-24", periods=4, freq="min"),
             "Age_sub_Age": [0, np.nan, 0, 0],
             "Marks_sub_Age": [-19.1, np.nan, -18.3, -17.4],
             "Age_sub_Marks": [19.1, np.nan, 18.3, 17.4],
@@ -302,7 +313,7 @@ def test_when_df_cols_are_integers(df_vartypes):
             1: ["London", "Manchester", "Liverpool", "Bristol"],
             2: [20, 21, 19, 18],
             3: [0.9, 0.8, 0.7, 0.6],
-            4: pd.date_range("2020-02-24", periods=4, freq="T"),
+            4: pd.date_range("2020-02-24", periods=4, freq="min"),
             "2_sub_2": [0, 0, 0, 0],
             "3_sub_2": [-19.1, -20.2, -18.3, -17.4],
             "2_sub_3": [19.1, 20.2, 18.3, 17.4],
@@ -318,7 +329,7 @@ def test_when_df_cols_are_integers(df_vartypes):
 
 
 @pytest.mark.parametrize("_func", [["div"], ["truediv"], ["floordiv"], ["mod"]])
-def test_error_when_division_by_zero(_func, df_vartypes):
+def test_error_when_division_by_zero_and_fill_value_is_none(_func, df_vartypes):
 
     df_zero = df_vartypes.copy()
     df_zero.loc[1, "Marks"] = 0
@@ -329,9 +340,54 @@ def test_error_when_division_by_zero(_func, df_vartypes):
         func=_func,
     )
     transformer.fit(df_vartypes)
-    with pytest.raises(ValueError):
+
+    with pytest.raises(ValueError) as record:
         transformer.transform(df_zero)
 
+    msg = (
+        "Some of the reference variables contain zeroes. Division by zero "
+        "does not exist. Replace zeros before using this transformer for division "
+        "or set `fill_value` to a number."
+    )
+    # check that the error message matches
+    assert str(record.value) == msg
+
+
+@pytest.mark.parametrize(
+    "_fill_value, _func",
+    [
+        (111.111, ["div"]),
+        (999, ["div"]),
+        (111.111, ["truediv"]),
+        (999, ["truediv"]),
+        (111.111, ["floordiv"]),
+        (999, ["floordiv"]),
+        (111.111, ["mod"]),
+        (999, ["mod"]),
+    ],
+)
+def test_fill_values_when_division_by_zero(_fill_value, _func, df_vartypes):
+    df_zero = df_vartypes.copy()
+    df_zero.loc[2, "Marks"] = 0
+    df_zero.loc[1, "Age"] = np.nan
+    df_zero.loc[3, "Age"] = np.inf
+
+    transformer = RelativeFeatures(
+        variables=["Age"],
+        reference=["Marks"],
+        fill_value=_fill_value,
+        func=_func,
+        missing_values="ignore",
+    )
+
+    X = transformer.fit_transform(df_zero)
+
+    new_var = f"Age_{_func[0]}_Marks"
+
+    assert X.loc[2, new_var] == _fill_value
+    np.testing.assert_equal(X.loc[1, "Age"], np.nan)
+    np.testing.assert_equal(X.loc[3, "Age"], np.inf)
+
 
 @pytest.mark.parametrize("_drop", [True, False])
 def test_get_feature_names_out(_drop, df_vartypes):
