@@ -1,13 +1,45 @@
 import warnings
 
-import numpy as np
 import pandas as pd
 import pytest
 from numpy import nan
+from sklearn.exceptions import NotFittedError
 
 from feature_engine.encoding import CountFrequencyEncoder
 
 
+# init parameters
+@pytest.mark.parametrize("enc_method", ["arbitrary", False, 1])
+def test_error_if_encoding_method_not_permitted_value(enc_method):
+    with pytest.raises(ValueError):
+        CountFrequencyEncoder(encoding_method=enc_method)
+
+
+@pytest.mark.parametrize(
+    "errors", ["empanada", False, 1, ("raise", "ignore"), ["ignore"]]
+)
+def test_error_if_unseen_gets_not_permitted_value(errors):
+    with pytest.raises(ValueError):
+        CountFrequencyEncoder(unseen=errors)
+
+
+@pytest.mark.parametrize(
+    "params", [("count", "raise", True), ("frequency", "ignore", False)]
+)
+def test_init_param_assignment(params):
+    enc = CountFrequencyEncoder(
+        encoding_method=params[0],
+        missing_values=params[1],
+        ignore_format=params[2],
+        unseen=params[1],
+    )
+    assert enc.encoding_method == params[0]
+    assert enc.missing_values == params[1]
+    assert enc.ignore_format == params[2]
+    assert enc.unseen == params[1]
+
+
+# fit and transform
 def test_encode_1_variable_with_counts(df_enc):
     # test case 1: 1 variable, counts
     encoder = CountFrequencyEncoder(encoding_method="count", variables=["var_A"])
@@ -115,10 +147,38 @@ def test_automatically_select_variables_encode_with_frequency(df_enc):
     pd.testing.assert_frame_equal(X, transf_df)
 
 
+def test_encoding_when_nan_in_fit_df(df_enc):
+    df = df_enc.copy()
+    df.loc[len(df)] = [nan, nan, nan]
+
+    encoder = CountFrequencyEncoder(
+        encoding_method="frequency",
+        missing_values="ignore",
+    )
+    encoder.fit(df_enc)
+
+    X = encoder.transform(
+        pd.DataFrame({"var_A": ["A", nan], "var_B": ["A", nan], "target": [1, 0]})
+    )
+
+    # transform params
+    pd.testing.assert_frame_equal(
+        X,
+        pd.DataFrame({"var_A": [0.3, nan], "var_B": [0.5, nan], "target": [1, 0]}),
+    )
+
+
 @pytest.mark.parametrize("enc_method", ["arbitrary", False, 1])
-def test_error_if_encoding_method_not_permitted_value(enc_method):
-    with pytest.raises(ValueError):
-        CountFrequencyEncoder(encoding_method=enc_method)
+def test_error_if_encoding_method_not_recognized_in_fit(enc_method, df_enc):
+    enc = CountFrequencyEncoder()
+    enc.encoding_method = enc_method
+    with pytest.raises(ValueError) as record:
+        enc.fit(df_enc)
+    msg = (
+        "Unrecognized value for encoding_method. It should be 'count' or "
+        f"'frequency'. Got {enc_method} instead."
+    )
+    assert str(record.value) == msg
 
 
 def test_warning_when_df_contains_unseen_categories(df_enc, df_enc_rare):
@@ -181,8 +241,14 @@ def test_no_error_triggered_when_df_contains_unseen_categories_and_unseen_is_enc
 def test_fit_raises_error_if_df_contains_na(errors, df_enc_na):
     # test case 4: when dataset contains na, fit method
     encoder = CountFrequencyEncoder(unseen=errors)
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError) as record:
         encoder.fit(df_enc_na)
+    msg = (
+        "Some of the variables in the dataset contain NaN. Check and "
+        "remove those before using this transformer or set the parameter "
+        "`missing_values='ignore'` when initialising this transformer."
+    )
+    assert str(record.value) == msg
 
 
 @pytest.mark.parametrize("errors", ["raise", "ignore", "encode"])
@@ -190,8 +256,14 @@ def test_transform_raises_error_if_df_contains_na(errors, df_enc, df_enc_na):
     # test case 4: when dataset contains na, transform method
     encoder = CountFrequencyEncoder(unseen=errors)
     encoder.fit(df_enc)
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError) as record:
         encoder.transform(df_enc_na)
+    msg = (
+        "Some of the variables in the dataset contain NaN. Check and "
+        "remove those before using this transformer or set the parameter "
+        "`missing_values='ignore'` when initialising this transformer."
+    )
+    assert str(record.value) == msg
 
 
 def test_zero_encoding_for_new_categories():
@@ -211,7 +283,7 @@ def test_zero_encoding_for_new_categories():
 
     # check that the counts are correct for both new and old
     expected_result = pd.DataFrame({"col1": [3, 0, 1, 3, 1], "col2": [2, 2, 1, 2, 0]})
-    pd.testing.assert_frame_equal(result, expected_result)
+    pd.testing.assert_frame_equal(result, expected_result, check_dtype=False)
 
 
 def test_zero_encoding_for_unseen_categories_if_unseen_is_encode():
@@ -231,7 +303,7 @@ def test_zero_encoding_for_unseen_categories_if_unseen_is_encode():
 
     # check that the counts are correct
     expected_result = pd.DataFrame({"col1": [3, 0, 1, 3, 1], "col2": [2, 2, 1, 2, 0]})
-    pd.testing.assert_frame_equal(result, expected_result)
+    pd.testing.assert_frame_equal(result, expected_result, check_dtype=False)
 
     # with frequency
     encoder = CountFrequencyEncoder(encoding_method="frequency", unseen="encode").fit(
@@ -308,7 +380,7 @@ def test_column_names_are_numbers(df_numeric_columns):
         1: [0.25, 0.25, 0.25, 0.25],
         2: [0.25, 0.25, 0.25, 0.25],
         3: [0.25, 0.25, 0.25, 0.25],
-        4: pd.date_range("2020-02-24", periods=4, freq="T"),
+        4: pd.date_range("2020-02-24", periods=4, freq="min"),
     }
 
     transf_df = pd.DataFrame(transf_df)
@@ -360,12 +432,6 @@ def test_variables_cast_as_category(df_enc_category_dtypes):
     assert X["var_A"].dtypes == float
 
 
-@pytest.mark.parametrize("errors", ["empanada", False, 1])
-def test_exception_if_unseen_gets_not_permitted_value(errors):
-    with pytest.raises(ValueError):
-        CountFrequencyEncoder(unseen=errors)
-
-
 def test_inverse_transform_when_no_unseen():
     df = pd.DataFrame({"words": ["dog", "dog", "cat", "cat", "cat", "bird"]})
     enc = CountFrequencyEncoder()
@@ -377,7 +443,7 @@ def test_inverse_transform_when_no_unseen():
 def test_inverse_transform_when_ignore_unseen():
     df1 = pd.DataFrame({"words": ["dog", "dog", "cat", "cat", "cat", "bird"]})
     df2 = pd.DataFrame({"words": ["dog", "dog", "cat", "cat", "cat", "frog"]})
-    df3 = pd.DataFrame({"words": ["dog", "dog", "cat", "cat", "cat", np.nan]})
+    df3 = pd.DataFrame({"words": ["dog", "dog", "cat", "cat", "cat", nan]})
     enc = CountFrequencyEncoder(unseen="ignore")
     enc.fit(df1)
     dft = enc.transform(df2)
@@ -387,8 +453,26 @@ def test_inverse_transform_when_ignore_unseen():
 def test_inverse_transform_when_encode_unseen():
     df1 = pd.DataFrame({"words": ["dog", "dog", "cat", "cat", "cat", "bird"]})
     df2 = pd.DataFrame({"words": ["dog", "dog", "cat", "cat", "cat", "frog"]})
-    df3 = pd.DataFrame({"words": ["dog", "dog", "cat", "cat", "cat", np.nan]})
+    df3 = pd.DataFrame({"words": ["dog", "dog", "cat", "cat", "cat", nan]})
     enc = CountFrequencyEncoder(unseen="encode")
     enc.fit(df1)
     dft = enc.transform(df2)
     pd.testing.assert_frame_equal(enc.inverse_transform(dft), df3)
+
+
+def test_inverse_transform_raises_non_fitted_error():
+    df1 = pd.DataFrame({"words": ["dog", "dog", "cat", "cat", "cat", "bird"]})
+    enc = CountFrequencyEncoder()
+
+    # Test when fit is not called prior to transform.
+    with pytest.raises(NotFittedError):
+        enc.inverse_transform(df1)
+
+    df1.loc[len(df1) - 1] = nan
+
+    with pytest.raises(ValueError):
+        enc.fit(df1)
+
+    # Test when fit is not called prior to transform.
+    with pytest.raises(NotFittedError):
+        enc.inverse_transform(df1)
