@@ -1,10 +1,37 @@
-import numpy as np
 import pandas as pd
 import pytest
+from numpy import nan
+from sklearn.exceptions import NotFittedError
 
 from feature_engine.encoding import MeanEncoder
 
 
+# test init params
+@pytest.mark.parametrize("params", [("raise", True, "auto"), ("ignore", False, 1)])
+def test_init_param_assignment(params):
+    MeanEncoder(
+        missing_values=params[0],
+        ignore_format=params[1],
+        unseen=params[0],
+        smoothing=params[2],
+    )
+
+
+@pytest.mark.parametrize(
+    "errors", ["empanada", False, 1, ("raise", "ignore"), ["ignore"]]
+)
+def test_error_if_unseen_gets_not_permitted_value(errors):
+    with pytest.raises(ValueError):
+        MeanEncoder(unseen=errors)
+
+
+@pytest.mark.parametrize("smoothing", ["hello", ["auto"], -1])
+def test_raises_error_when_not_allowed_smoothing_param_in_init(smoothing):
+    with pytest.raises(ValueError):
+        MeanEncoder(smoothing=smoothing)
+
+
+# fit and transform
 def test_user_enters_1_variable(df_enc):
     # test case 1: 1 variable
     encoder = MeanEncoder(variables=["var_A"])
@@ -114,6 +141,34 @@ def test_automatically_find_variables(df_enc):
     pd.testing.assert_frame_equal(X, transf_df[["var_A", "var_B"]])
 
 
+def test_encoding_when_nan_in_fit_df(df_enc):
+    df = df_enc.copy()
+    df.loc[len(df)] = [nan, nan, 0]
+
+    encoder = MeanEncoder(missing_values="ignore")
+    encoder.fit(df[["var_A", "var_B"]], df["target"])
+
+    X = encoder.transform(
+        pd.DataFrame(
+            {
+                "var_A": ["A", nan],
+                "var_B": ["A", nan],
+            }
+        )
+    )
+
+    # transform params
+    pd.testing.assert_frame_equal(
+        X,
+        pd.DataFrame(
+            {
+                "var_A": [0.3333333333333333, nan],
+                "var_B": [0.2, nan],
+            }
+        ),
+    )
+
+
 def test_warning_if_transform_df_contains_categories_not_present_in_fit_df(
     df_enc, df_enc_rare
 ):
@@ -145,17 +200,29 @@ def test_warning_if_transform_df_contains_categories_not_present_in_fit_df(
 
 def test_fit_raises_error_if_df_contains_na(df_enc_na):
     # test case 4: when dataset contains na, fit method
-    with pytest.raises(ValueError):
-        encoder = MeanEncoder()
+    encoder = MeanEncoder()
+    with pytest.raises(ValueError) as record:
         encoder.fit(df_enc_na[["var_A", "var_B"]], df_enc_na["target"])
+    msg = (
+        "Some of the variables in the dataset contain NaN. Check and "
+        "remove those before using this transformer or set the parameter "
+        "`missing_values='ignore'` when initialising this transformer."
+    )
+    assert str(record.value) == msg
 
 
 def test_transform_raises_error_if_df_contains_na(df_enc, df_enc_na):
     # test case 4: when dataset contains na, transform method
-    with pytest.raises(ValueError):
-        encoder = MeanEncoder()
-        encoder.fit(df_enc[["var_A", "var_B"]], df_enc["target"])
-        encoder.transform(df_enc_na)
+    encoder = MeanEncoder()
+    encoder.fit(df_enc[["var_A", "var_B"]], df_enc["target"])
+    with pytest.raises(ValueError) as record:
+        encoder.transform(df_enc_na[["var_A", "var_B"]])
+    msg = (
+        "Some of the variables in the dataset contain NaN. Check and "
+        "remove those before using this transformer or set the parameter "
+        "`missing_values='ignore'` when initialising this transformer."
+    )
+    assert str(record.value) == msg
 
 
 def test_user_enters_1_variable_ignore_format(df_enc_numeric):
@@ -366,11 +433,6 @@ def test_value_smoothing(df_enc):
     pd.testing.assert_frame_equal(X, transf_df[["var_A", "var_B"]])
 
 
-def test_error_if_rare_labels_not_permitted_value():
-    with pytest.raises(ValueError):
-        MeanEncoder(unseen="empanada")
-
-
 def test_encoding_new_categories(df_enc):
     df_unseen = pd.DataFrame({"var_A": ["D"], "var_B": ["D"]})
     encoder = MeanEncoder(unseen="encode")
@@ -391,7 +453,7 @@ def test_inverse_transform_when_no_unseen():
 def test_inverse_transform_when_ignore_unseen():
     df1 = pd.DataFrame({"words": ["dog", "dog", "cat", "cat", "cat", "bird"]})
     df2 = pd.DataFrame({"words": ["dog", "dog", "cat", "cat", "cat", "frog"]})
-    df3 = pd.DataFrame({"words": ["dog", "dog", "cat", "cat", "cat", np.nan]})
+    df3 = pd.DataFrame({"words": ["dog", "dog", "cat", "cat", "cat", nan]})
     y = [1, 0, 1, 0, 1, 0]
     enc = MeanEncoder(unseen="ignore")
     enc.fit(df1, y)
@@ -406,11 +468,29 @@ def test_inverse_transform_when_encode_unseen():
     enc = MeanEncoder(unseen="encode")
     enc.fit(df1, y)
     dft = enc.transform(df2)
-    with pytest.raises(NotImplementedError):
+    with pytest.raises(NotImplementedError) as record:
         enc.inverse_transform(dft)
+    msg = (
+        "inverse_transform is not implemented for this transformer when "
+        "`unseen='encode'`."
+    )
+    assert str(record.value) == msg
 
 
-@pytest.mark.parametrize("smoothing", ["hello", ["auto"], -1])
-def test_raises_error_when_not_allowed_smoothing_param_in_init(smoothing):
+def test_inverse_transform_raises_non_fitted_error():
+    df1 = pd.DataFrame({"words": ["dog", "dog", "cat", "cat", "cat", "bird"]})
+    y = [1, 0, 1, 0, 1, 0]
+    enc = MeanEncoder()
+
+    # Test when fit is not called prior to transform.
+    with pytest.raises(NotFittedError):
+        enc.inverse_transform(df1)
+
+    df1.loc[len(df1) - 1] = nan
+
     with pytest.raises(ValueError):
-        MeanEncoder(smoothing=smoothing)
+        enc.fit(df1, y)
+
+    # Test when fit is not called prior to transform.
+    with pytest.raises(NotFittedError):
+        enc.inverse_transform(df1)
