@@ -1,7 +1,9 @@
 # Authors: Soledad Galli <solegalli@gprotonmail.com>
 # License: BSD 3 clause
 
+import numpy as np
 import pandas as pd
+import pytest
 
 from feature_engine.outliers import OutlierTrimmer
 
@@ -79,3 +81,31 @@ def test_transformer_ignores_na_in_df(df_na):
 
     pd.testing.assert_frame_equal(X, df_transf)
     assert len(X) == 5
+
+
+def test_transform_x_t(df_normal_dist):
+    y = pd.Series(np.zeros(len(df_normal_dist)))
+    transformer = OutlierTrimmer(capping_method="mad", tail="right", fold=1)
+    X = transformer.fit_transform(df_normal_dist)
+    assert len(X) != len(y)
+
+    Xt, yt = transformer.transform_x_y(df_normal_dist, y)
+    assert len(Xt) == len(yt)
+    assert len(Xt) != len(df_normal_dist)
+    assert (Xt.index == yt.index).all()
+
+
+@pytest.mark.parametrize(
+    "strings,expected",
+    [("gaussian", 3), ("iqr", 1.5), ("mad", 3.29), ("quantiles", 0.05)],
+)
+def test_auto_fold_default_value(strings, expected, df_normal_dist):
+    transformer = OutlierTrimmer(capping_method=strings, fold="auto")
+    transformer.fit(df_normal_dist)
+    assert transformer.fold_ == expected
+
+
+def test_low_variation(df_normal_dist):
+    transformer = OutlierTrimmer(capping_method="mad")
+    with pytest.raises(ValueError):
+        transformer.fit(df_normal_dist // 10)
