@@ -1,6 +1,7 @@
 import numpy as np
 import pandas as pd
 import pytest
+from sklearn import __version__ as skl_version
 from sklearn.base import clone
 from sklearn.datasets import fetch_california_housing
 from sklearn.decomposition import PCA
@@ -50,11 +51,21 @@ _selectors = [
 ]
 
 
+def _OneHotEncoder(sparse, drop=None, dtype=np.float64) -> OneHotEncoder:
+    """OneHotEncoder sparse argument has been renamed as sparse_output
+    in scikitlearn >=1.2"""
+
+    if skl_version.split(".")[0] == "1" and int(skl_version.split(".")[1]) >= 2:
+        return OneHotEncoder(sparse_output=sparse, drop=drop, dtype=dtype)
+    else:
+        return OneHotEncoder(sparse=sparse, drop=drop, dtype=dtype)
+
+
 @pytest.mark.parametrize(
     "transformer",
     [
         SimpleImputer(),
-        OneHotEncoder(sparse=False),
+        _OneHotEncoder(sparse=False),
         StandardScaler(),
         SelectKBest(),
     ],
@@ -78,7 +89,7 @@ def test_error_when_transformer_is_estimator(transformer, df_na):
         MissingIndicator(),
         KBinsDiscretizer(encode="one_hot"),
         SimpleImputer(add_indicator=True),
-        OneHotEncoder(sparse=True),
+        _OneHotEncoder(sparse=True),
     ],
 )
 def test_error_not_implemented_transformer(transformer, df_na):
@@ -319,7 +330,7 @@ def test_sklearn_ohe_object_one_feature(df_vartypes):
     variables_to_encode = ["Name"]
 
     transformer = SklearnTransformerWrapper(
-        transformer=OneHotEncoder(sparse=False, dtype=np.int64),
+        transformer=_OneHotEncoder(sparse=False, dtype=np.int64),
         variables=variables_to_encode,
     )
 
@@ -341,7 +352,7 @@ def test_sklearn_ohe_object_many_features(df_vartypes):
     variables_to_encode = ["Name", "City"]
 
     transformer = SklearnTransformerWrapper(
-        transformer=OneHotEncoder(sparse=False, dtype=np.int64),
+        transformer=_OneHotEncoder(sparse=False, dtype=np.int64),
         variables=variables_to_encode,
     )
 
@@ -367,7 +378,7 @@ def test_sklearn_ohe_numeric(df_vartypes):
     variables_to_encode = ["Age"]
 
     transformer = SklearnTransformerWrapper(
-        transformer=OneHotEncoder(sparse=False, dtype=np.int64),
+        transformer=_OneHotEncoder(sparse=False, dtype=np.int64),
         variables=variables_to_encode,
     )
 
@@ -387,7 +398,7 @@ def test_sklearn_ohe_numeric(df_vartypes):
 
 def test_sklearn_ohe_all_features(df_vartypes):
     transformer = SklearnTransformerWrapper(
-        transformer=OneHotEncoder(sparse=False, dtype=np.int64)
+        transformer=_OneHotEncoder(sparse=False, dtype=np.int64)
     )
 
     ref = pd.DataFrame(
@@ -443,7 +454,7 @@ def test_sklearn_ohe_with_crossvalidation():
             (
                 "encode_cat",
                 SklearnTransformerWrapper(
-                    transformer=OneHotEncoder(drop="first", sparse=False),
+                    transformer=_OneHotEncoder(drop="first", sparse=False),
                     variables=["AveBedrms_cat"],
                 ),
             ),
@@ -459,7 +470,7 @@ def test_sklearn_ohe_with_crossvalidation():
 
 
 def test_wrap_one_hot_encoder_get_features_name_out(df_vartypes):
-    ohe_wrap = SklearnTransformerWrapper(transformer=OneHotEncoder(sparse=False))
+    ohe_wrap = SklearnTransformerWrapper(transformer=_OneHotEncoder(sparse=False))
     ohe_wrap.fit(df_vartypes)
 
     expected_features_all = [
@@ -541,7 +552,6 @@ def test_error_when_inverse_transform_not_implemented(transformer):
 )
 @pytest.mark.parametrize("transformer", _transformers)
 def test_get_feature_names_out_transformers(varlist, transformer):
-
     X = fetch_california_housing(as_frame=True).frame
     tr_wrap = SklearnTransformerWrapper(transformer=transformer, variables=varlist)
     Xw = tr_wrap.fit_transform(X)
@@ -600,9 +610,8 @@ def test_get_feature_names_out_polynomialfeatures(varlist):
 
 @pytest.mark.parametrize("varlist", [["Name", "City"], None])
 def test_get_feature_names_out_ohe(varlist, df_vartypes):
-
     transformer = SklearnTransformerWrapper(
-        transformer=OneHotEncoder(sparse=False, dtype=np.int64),
+        transformer=_OneHotEncoder(sparse=False, dtype=np.int64),
         variables=varlist,
     )
 
